/*

** PURPOSE: 	This do-file creates the panel base data. 
				It uses all follow up rounds, the baseline and the listing data
				
*/	

		
clear
clear matrix
clear mata
set matsize 5000
set mem 4000m
set more off
set maxvar 30000
version 10.1


*-- Directory
cap cd "C:\Users\wb404534\Dropbox\BRIE Malawi"
cap cd "C:\Users\wb338977\Dropbox\BRIE Malawi"
cap cd "C:\Users\Adriana\Dropbox\World Bank\Malawi\BRIE box"

* Paths
global working_data	"BR intervention\Data"
global baseline	"baseline survey\Data"
global follow_up	"follow up survey\Data"
global second_follow_up "Second Follow Up Survey\Data"
global third_follow_up	"Third Follow Up Survey\Data"
global fourth_follow_up "Endline Survey\Data"
global panel		"Panel\final panel data"
global analysis		"Endline Analysis\Results"


global short_working_data "Paper for pub\Data\Inputs for panel"

*-- Open baseline data
*use "$baseline\Working Data\Baseline_Malawi_clean_September_2018_BS.dta"
use "$short_working_data\Baseline_Malawi_clean_September_2018_BS.dta"

*-- SOME DATA CLEANING/PREPARATION:
rename offer interventions
encode interventions, gen (offer)
drop interventions
rename treatment BR_intervention
tab BR_intervention,m


gen treat1_BR = (offer==2)
gen treat2_BR_TPIN = (offer==1)
gen treat3_BR_Bank = (offer==3)
gen control = (offer==.)
gen treated = (control==0)


gen treatment = 1 if treat1_BR==1
replace treatment = 2 if treat2_BR_TPIN==1
replace treatment = 3 if treat3_BR_Bank==1
replace treatment = 4 if control==1
label define treatment_status 1 "BR Certificate" 2 "BR + TPIN" 3 "BR + Bank" 4 "Control"
label values treatment treatment_status
tab treatment,m

*-- We open admin data
cap drop _merge
*merge m:1 id using "randomization\strata_llw_&_bt.dta"
merge m:1 id using "$short_working_data\strata_llw_&_bt.dta"
tab _merge,m
drop _m
tab strata, gen (strata_)

count
*3002*


gen int_BR=treat1_BR*female
gen int_BR_TPIN=treat2_BR_TPIN*female
gen int_BR_Bank=treat3_BR_Bank*female

gen int_city_BR=treat1_BR*lilongwe
gen int_city_BR_TPIN=treat2_BR_TPIN*lilongwe
gen int_city_BR_Bank=treat3_BR_Bank*lilongwe


merge 1:1 id using "$short_working_data\survey_completion.dta"
*merge 1:1 id using "$follow_up\temp\survey_completion.dta"
drop _merge

replace business_op = (s1q1==1)
replace business_op = 1 if refusal=="1"
gen int_busop_female=business_oper*female

gen spouse_decision_business = (s2q6==2 | s2q6==5)
gen int_spouse_decision=spouse_decision_business*female


merge 1:1 id using "$short_working_data\reasons for people that did not take BRC_edited.dta"
*merge 1:1 id using "$working_data\final_data\reasons for people that did not take BRC_edited.dta"
drop if _merge==2
drop _merge

*-- We open follow-up data
merge 1:1 id using "$short_working_data\First_followup_Malawi_clean_September_2018_F.dta"
*merge 1:1 id using "$follow_up\Working Data\First_followup_Malawi_clean_September_2018_F.dta"
drop if _merge==2
drop _merge

merge 1:1 id using "$short_working_data\Second_followup_Malawi_clean_September_2018_F2.dta"
*merge 1:1 id using "$second_follow_up\Working Data\Second_followup_Malawi_clean_September_2018_F2.dta"
drop if _merge==2
drop _merge

merge 1:1 id using "$short_working_data\Third_followup_Malawi_clean_September_2018_F3.dta"
*merge 1:1 id using "$third_follow_up\Working Data\Third_followup_Malawi_clean_September_2018_F3.dta"
drop if _merge==2
drop _merge

merge 1:1 id using "$short_working_data\Fourth_followup_Malawi_clean_September_2018_F4.dta"
*merge 1:1 id using "$fourth_follow_up\Working Data\Fourth_followup_Malawi_clean_September_2018_F4.dta"
drop if _merge==2
drop _merge


*-- SOME DATA CLEANING/PREPARATION:

*****certificate delivered*********
replace certificate_delivered = "0" if certificate_delivered!="Yes"
replace certificate_delivered = "1" if certificate_delivered=="Yes"
destring certificate_d, replace
label define certificate_yes 1 "Yes" 0 "No"
label values certificate_delivered certificate_yes
tab certificate_delivered
rename certificate_delivered took_br

tab offer,m
*BR + (BR+TPIN) + (BR+TPIN+Training)=75%
tab registration,m /* 74.78%*/
tab BR_training
tab BR_only
tab BR_TPIN 

tab treat1_BR,m
tab treat2_BR_TPIN
tab treat3_BR_Bank

*******reasons for people not taking BRC*******
tab reasoncertificatenotdelivered, m
tab reasoncertificatenotdelivered female if treatment==2, m r col
tab reasoncertificatenotdelivered took_br if treatment!=4, m
replace reasoncertificatenotdelivered=8 if took_br==0 & treatment!=4 & reasoncertificatenotdelivered==.

gen reasonBRCnot_combined = .
replace reasonBRCnot_combined = 1 if reasoncertificatenotdelivered==1 | reasoncertificatenotdelivered==2
replace reasonBRCnot_combined = 2 if reasoncertificatenotdelivered==3
replace reasonBRCnot_combined = 3 if reasoncertificatenotdelivered==4 | reasoncertificatenotdelivered==6 | reasoncertificatenotdelivered==7
replace reasonBRCnot_combined = 4 if reasoncertificatenotdelivered==5
replace reasonBRCnot_combined = 5 if reasoncertificatenotdelivered==8
replace reasonBRCnot_combined = 6 if reasoncertificatenotdelivered==. & treatment!=4
label define reasonBRCnot_combined 1 "Already registered" 2 "Neeeded to consult spouse" 3 "Failed to locate/closed/moved" 4 "Refusal" 5 "No info on reason" 6 "Accepted registration"
label values reasonBRCnot_combined reasonBRCnot_combined
tab reasonBRCnot_combined, gen(reasonBRCnot_combined)

foreach var of varlist reasonBRCnot_combined* {
gen f`var' = female*`var'
gen m`var' = (1-female)*`var'
}

*-- ATTRITION AND CLOSURE ANALYSIS ********************************

************** First follow-up ******************
tab F_no_attrition, m
cap drop F_attrition
gen F_attrition= (F_no_attrition==.)
tab F_attrition, m
tab F_has_business, m
tab F_attrition F_has_business, m
tab F_closure, m

cap drop F_closure
gen F_closure= (F_has_business==0) 
replace F_closure=. if F_attrition==1


************** Second follow-up ******************
tab F2_no_attrition, m
cap drop F2_attrition
gen F2_attrition= (F2_no_attrition==.)
tab F2_attrition, m
tab F2_has_business, m
tab F2_attrition F2_has_business, m
tab F2_closure, m

************** Third follow-up ******************
tab F3_no_attrition, m
replace F3_attrition=1 if F3_no_attrition!=1
tab F3_attrition, m
replace F3_has_business=0 if F3_no_attrition!=1
tab F3_has_business, m
 tab F3_attrition F3_has_business, m
tab F3_closure, m


************** Fourth follow-up ******************
tab F4_no_attrition, m
replace F4_attrition=1 if F4_no_attrition!=1
tab F4_attrition, m
replace F4_has_business=0 if F4_no_attrition!=1
tab F4_has_business, m
 tab F4_attrition F4_has_business, m
tab F4_closure, m



*-- WE CREATE PANEL

* controls
global controls strata_* 


****************save 4th follow-up relevant data for panel*****************
preserve

#d ;
keep id treatment treat1_BR treat2_BR_TPIN treat3_BR_Bank control int_BR int_BR_TPIN int_BR_Bank int_city_BR int_city_BR_TPIN int_city_BR_Bank reasonBRCnot_* freasonBRCnot_* took_br brc_tpin attendedtrainingday1 attendedtrainingday2 bankaccountopened City 
	 F4_has_business F4_no_attrition F4_attrition F4_closure $controls 
	 female lilongwe large_size firm_age high_capture Manufacturing Retail Services  					
	/* Baseline outcomes */
	 has_BRC has_TPIN has_city_council Total_workers2 Business_owner owner_started own_space innov electricity_access Num_competitors time_to_nearestbank owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed Seconday_completed Higher_education high_capture Financial_knowledge mother_enterpreneur mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt  usd_Revenue_lastmonth Revenue_lastmonth usd_Revenue_lastweek Revenue_lastweek usd_Revenue_lastmonth99 Revenue_lastmonth99 usd_Revenue_lastweek99 Revenue_lastweek99 ihst_Revenue_lastmonth usd_Profit_lastmonth  Profit_lastmonth usd_Profit_lastweek Profit_lastweek usd_Profit_lastmonth99 Profit_lastmonth99 usd_Profit_lastweek99  Profit_lastweek99 ihst_Profit_lastmonth	Total_workers2 number_days_workmonth usd_capital capital usd_assets assets propmaleworkers  borrowed_in_past usd_amount_recentloan amount_recentloan  any_account banks_any_account banksonly_bus_account account_used_only_business save_home  rosca_sacco banks_saving usd_saved_amount saved_amount usd_saved_amount99 saved_amount99 usd_saved_amount_bank saved_amount_bank mix_bus_hh bank_loan    usd_debt_outst_include  debt_outst_include benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown confiscation sexually_harassed sexuallyHarassed other_harassment receipt  num_customers num_customers_month chamber export_license tender changes_location usd_loan_can_raise loan_can_raise insurance Business_plan budget financial_records advert  other_activity netw_anyline contact_bank paidcitycouncilmktfee  taxescosts t_courts  t_police t_govern t_city_council t_tax_aut no_inspected_taxes no_inspected_other confident_no_bribe
	/* Follow-up outcomes */
	 F4_has_BRC F4_has_TPIN F4_has_city_council F4_Revenue_lastmonth F4_Revenue_lastweek F4_Revenue_lastmonth99 F4_Revenue_lastweek99 F4_ihst_Revenue_lastmonth	 F4_Profit_lastmonth F4_Profit_lastweek F4_Profit_lastmonth99 F4_Profit_lastweek99 F4_ihst_Profit_lastmonth F4_banksonly_bus_account F4_export_license F4_chamber F4_tender F4_changes_location F4_loan_can_raise F4_amount_recentloan F4_insurance  F4_saved_amount F4_saved_amount_bank F4_mix_bus_hh F4_financial_records  F4_contact_bank F4_taxescosts F4_receipt F4_t_courts  F4_t_police F4_t_govern F4_t_city_council F4_t_tax_aut F4_banks_any_account F4_banksonly_bus_account  F4_account_used_only_business F4_save_home F4_rosca_sacco F4_banks_saving F4_inspected_municipality F4_inspected_taxes F4_inspected_other F4_Asked_for_bribe F4_confident_no_bribe F4_threats_to_shutdown F4_confiscation F4_sexually_harassed F4_other_harassment
	/* missings vars */
	 missBShas_BRC missBShas_TPIN missBShas_city_council missBSRevenue_lastmonth missBSRevenue_lastweek missBSRevenue_lastmonth99 missBSRevenue_lastweek99 missBSihst_Revenue_lastmonth	missBSProfit_lastmonth missBSProfit_lastweek missBSProfit_lastmonth99 missBSProfit_lastweek99 missBSihst_Profit_lastmonth	missBSbanksonly_bus_account missBSchamber missBSexport_license  missBStender missBSchanges_location missBSusd_loan_can_raise missBSamount_recentloan  missBSinsurance  missBSsaved_amount_bank missBSmix_bus_hh missBSfinancial_records missBScontact_bank missBStaxescosts missBSreceipt missBSt_courts  missBSt_police missBSt_govern missBSt_city_council missBSt_tax_aut missBSbanks_any_account missBSbanksonly_bus_account  missBSaccount_used_only_business missBSsave_home missBSrosca_sacco missBSbanks_saving missBSpropmaleworkers missBSinspected_municipality missBSAsked_for_bribe missBSthreats_to_shutdown missBSconfiscation missBSsexually_harassed missBSother_harassment missBScapital missBSno_inspected_taxes missBSno_inspected_other missBSconfident_no_bribe 
	 F4_missFhas_BRC F4_missFhas_TPIN F4_missFhas_city_council F4_missFRevenue_lastmonth F4_missFRevenue_lastweek F4_missFRevenue_lastmonth99 F4_missFRevenue_lastweek99	F4_missFProfit_lastmonth F4_missFProfit_lastweek F4_missFProfit_lastmonth99 F4_missFProfit_lastweek99 F4_missFbanksonly_bus_account F4_missFchamber F4_missFexport_license F4_missFtender F4_missFchanges_location  F4_missFloan_can_raise F4_missFamount_recentloan  F4_missFinsurance  F4_missFmix_bus_hh F4_missFfinancial_records F4_missFcontact_bank F4_missFtaxescosts F4_missFreceipt F4_missFt_courts  F4_missFt_police F4_missFt_govern F4_missFt_city_council F4_missFt_tax_aut F4_missFbanks_any_account F4_missFbanksonly_bus_account  F4_missFaccount_used_only_bus F4_missFsave_home F4_missFrosca_sacco F4_missFbanks_saving F4_missFno_inspected_municipalit F4_missFno_inspected_taxes F4_missFno_inspected_other F4_missFno_Asked_for_bribe F4_missFconfident_no_bribe F4_missFno_threats_to_shutdown  F4_missFno_confiscation F4_missFno_sexually_harassed F4_missFno_other_harassment F4_missFcapital F4_missFusd_saved_amount
	F4_missFno_rosca_sacco F4_missFno_save_home F4_missFusd_saved_amount_bank  F4_missFno_inspected_municipalit F4_missFno_inspected_taxes  F4_missFno_inspected_other F4_missFno_Asked_for_bribe F4_missFconfident_no_bribe F4_missFno_threats_to_shutdown F4_missFno_confiscation F4_missFno_sexually_harassed F4_missFno_other_harassment
	  
	  ;
#d cr 


renpfix F4_ F_
renpfix F_missF missF

gen round_fup = 4

save "$panel\BRIE_4thfollowup_forpanel.dta", replace

restore


****************save 3rd follow-up relevant data for panel*****************
preserve

#d ;
keep id treatment treat1_BR treat2_BR_TPIN treat3_BR_Bank control int_BR int_BR_TPIN int_BR_Bank int_city_BR int_city_BR_TPIN int_city_BR_Bank reasonBRCnot_* freasonBRCnot_* took_br brc_tpin attendedtrainingday1 attendedtrainingday2 bankaccountopened City 
	 F3_has_business F3_no_attrition F3_attrition F3_closure $controls 
	 female lilongwe large_size firm_age high_capture Manufacturing Retail Services  					
	/* Baseline outcomes */
	 has_BRC has_TPIN has_city_council Total_workers2 Business_owner owner_started own_space innov electricity_access Num_competitors time_to_nearestbank owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed Seconday_completed Higher_education high_capture Financial_knowledge mother_enterpreneur mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt  usd_Revenue_lastmonth Revenue_lastmonth usd_Revenue_lastweek Revenue_lastweek usd_Revenue_lastmonth99 Revenue_lastmonth99 usd_Revenue_lastweek99 Revenue_lastweek99 ihst_Revenue_lastmonth usd_Profit_lastmonth  Profit_lastmonth usd_Profit_lastweek Profit_lastweek usd_Profit_lastmonth99 Profit_lastmonth99 usd_Profit_lastweek99  Profit_lastweek99 ihst_Profit_lastmonth	Total_workers2 number_days_workmonth usd_capital capital usd_assets assets propmaleworkers  borrowed_in_past usd_amount_recentloan amount_recentloan  any_account banks_any_account banksonly_bus_account account_used_only_business save_home  rosca_sacco banks_saving usd_saved_amount saved_amount usd_saved_amount99 saved_amount99 usd_saved_amount_bank saved_amount_bank mix_bus_hh bank_loan    usd_debt_outst_include  debt_outst_include benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown confiscation sexually_harassed sexuallyHarassed other_harassment receipt  num_customers num_customers_month chamber export_license tender changes_location usd_loan_can_raise loan_can_raise insurance Business_plan budget financial_records advert  other_activity netw_anyline contact_bank paidcitycouncilmktfee  taxescosts t_courts  t_police t_govern t_city_council t_tax_aut  no_inspected_taxes no_inspected_other confident_no_bribe
	/* Follow-up outcomes */
	 F3_has_BRC F3_has_TPIN F3_has_city_council F3_Revenue_lastmonth F3_Revenue_lastweek F3_Revenue_lastmonth99 F3_Revenue_lastweek99 F3_ihst_Revenue_lastmonth	 F3_Profit_lastmonth F3_Profit_lastweek F3_Profit_lastmonth99 F3_Profit_lastweek99 F3_ihst_Profit_lastmonth F3_banksonly_bus_account F3_export_license F3_chamber F3_tender F3_changes_location F3_loan_can_raise F3_amount_recentloan F3_insurance  F3_saved_amount F3_saved_amount_bank F3_mix_bus_hh F3_financial_records  F3_contact_bank F3_taxescosts F3_receipt F3_t_courts  F3_t_police F3_t_govern F3_t_city_council F3_t_tax_aut F3_banks_any_account F3_banksonly_bus_account  F3_account_used_only_business F3_save_home F3_rosca_sacco F3_banks_saving F3_inspected_municipality F3_inspected_taxes F3_inspected_other F3_Asked_for_bribe F3_confident_no_bribe F3_threats_to_shutdown F3_confiscation F3_sexually_harassed F3_other_harassment
	/* missings vars */
	 missBShas_BRC missBShas_TPIN missBShas_city_council missBSRevenue_lastmonth missBSRevenue_lastweek missBSRevenue_lastmonth99 missBSRevenue_lastweek99 missBSihst_Revenue_lastmonth	missBSProfit_lastmonth missBSProfit_lastweek missBSProfit_lastmonth99 missBSProfit_lastweek99 missBSihst_Profit_lastmonth	missBSbanksonly_bus_account missBSchamber missBSexport_license  missBStender missBSchanges_location missBSusd_loan_can_raise missBSamount_recentloan  missBSinsurance  missBSsaved_amount_bank missBSmix_bus_hh missBSfinancial_records missBScontact_bank missBStaxescosts missBSreceipt missBSt_courts  missBSt_police missBSt_govern missBSt_city_council missBSt_tax_aut missBSbanks_any_account missBSbanksonly_bus_account  missBSaccount_used_only_business missBSsave_home missBSrosca_sacco missBSbanks_saving missBSpropmaleworkers missBSinspected_municipality missBSAsked_for_bribe missBSthreats_to_shutdown missBSconfiscation missBSsexually_harassed missBSother_harassment missBScapital missBSno_inspected_taxes missBSno_inspected_other missBSconfident_no_bribe 
	 F3_missFhas_BRC F3_missFhas_TPIN F3_missFhas_city_council F3_missFRevenue_lastmonth F3_missFRevenue_lastweek F3_missFRevenue_lastmonth99 F3_missFRevenue_lastweek99	F3_missFProfit_lastmonth F3_missFProfit_lastweek F3_missFProfit_lastmonth99 F3_missFProfit_lastweek99 F3_missFbanksonly_bus_account F3_missFchamber F3_missFexport_license F3_missFtender F3_missFchanges_location  F3_missFloan_can_raise F3_missFamount_recentloan  F3_missFinsurance  F3_missFmix_bus_hh F3_missFfinancial_records F3_missFcontact_bank F3_missFtaxescosts F3_missFreceipt F3_missFt_courts  F3_missFt_police F3_missFt_govern F3_missFt_city_council F3_missFt_tax_aut F3_missFbanks_any_account F3_missFbanksonly_bus_account  F3_missFaccount_used_only_bus F3_missFsave_home F3_missFrosca_sacco F3_missFbanks_saving F3_missFno_inspected_municipalit F3_missFno_inspected_taxes F3_missFno_inspected_other F3_missFno_Asked_for_bribe F3_missFconfident_no_bribe F3_missFno_threats_to_shutdown  F3_missFno_confiscation F3_missFno_sexually_harassed F3_missFno_other_harassment F3_missFcapital F3_missFusd_saved_amount
	 F3_missFno_rosca_sacco F3_missFno_save_home F3_missFusd_saved_amount_bank F3_missFno_inspected_municipalit F3_missFno_inspected_taxes  F3_missFno_inspected_other F3_missFno_Asked_for_bribe F3_missFconfident_no_bribe F3_missFno_threats_to_shutdown F3_missFno_confiscation F3_missFno_sexually_harassed F3_missFno_other_harassment
	 ;
#d cr 

renpfix F3_ F_
renpfix F_missF missF

gen round_fup = 3

save "$panel\BRIE_3rdfollowup_forpanel.dta", replace

restore


****************save 2nd follow-up relevant data for panel*****************
preserve

#d ;
keep id treatment treat1_BR treat2_BR_TPIN treat3_BR_Bank control int_BR int_BR_TPIN int_BR_Bank int_city_BR int_city_BR_TPIN int_city_BR_Bank reasonBRCnot_* freasonBRCnot_* took_br brc_tpin attendedtrainingday1 attendedtrainingday2 bankaccountopened City 
	 F2_has_business F2_no_attrition F2_attrition F2_closure $controls 
	 female lilongwe large_size firm_age high_capture Manufacturing Retail Services  					
	/* Baseline outcomes */
	 has_BRC has_TPIN has_city_council Total_workers2 Business_owner owner_started own_space innov electricity_access Num_competitors time_to_nearestbank owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed Seconday_completed Higher_education high_capture Financial_knowledge mother_enterpreneur mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt  usd_Revenue_lastmonth Revenue_lastmonth usd_Revenue_lastweek Revenue_lastweek usd_Revenue_lastmonth99 Revenue_lastmonth99 usd_Revenue_lastweek99 Revenue_lastweek99 ihst_Revenue_lastmonth usd_Profit_lastmonth  Profit_lastmonth usd_Profit_lastweek Profit_lastweek usd_Profit_lastmonth99 Profit_lastmonth99 usd_Profit_lastweek99  Profit_lastweek99 ihst_Profit_lastmonth	Total_workers2 number_days_workmonth usd_capital capital usd_assets assets propmaleworkers  borrowed_in_past usd_amount_recentloan amount_recentloan  any_account banks_any_account banksonly_bus_account account_used_only_business save_home  rosca_sacco banks_saving usd_saved_amount saved_amount usd_saved_amount99 saved_amount99 usd_saved_amount_bank saved_amount_bank mix_bus_hh bank_loan    usd_debt_outst_include  debt_outst_include benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown confiscation sexually_harassed sexuallyHarassed other_harassment receipt  num_customers num_customers_month chamber export_license tender changes_location usd_loan_can_raise loan_can_raise insurance Business_plan budget financial_records advert  other_activity netw_anyline contact_bank paidcitycouncilmktfee  taxescosts t_courts  t_police t_govern t_city_council t_tax_aut no_inspected_taxes no_inspected_other confident_no_bribe
	/* Follow-up outcomes */
	 F2_has_BRC F2_has_TPIN F2_has_city_council F2_Revenue_lastmonth F2_Revenue_lastweek F2_Revenue_lastmonth99 F2_Revenue_lastweek99 F2_ihst_Revenue_lastmonth	 F2_Profit_lastmonth F2_Profit_lastweek F2_Profit_lastmonth99 F2_Profit_lastweek99 F2_ihst_Profit_lastmonth F2_banksonly_bus_account F2_export_license F2_chamber F2_tender F2_changes_location F2_loan_can_raise F2_amount_recentloan F2_insurance  F2_saved_amount F2_saved_amount_bank F2_mix_bus_hh F2_financial_records  F2_contact_bank F2_taxescosts F2_receipt F2_t_courts  F2_t_police F2_t_govern F2_t_city_council F2_t_tax_aut F2_banks_any_account F2_banksonly_bus_account  F2_account_used_only_business F2_save_home F2_rosca_sacco F2_banks_saving F2_inspected_municipality F2_inspected_taxes F2_inspected_other F2_Asked_for_bribe F2_confident_no_bribe F2_threats_to_shutdown F2_confiscation F2_sexually_harassed F2_other_harassment
	/* missings vars */
	 missBShas_BRC missBShas_TPIN missBShas_city_council missBSRevenue_lastmonth missBSRevenue_lastweek missBSRevenue_lastmonth99 missBSRevenue_lastweek99 missBSihst_Revenue_lastmonth	missBSProfit_lastmonth missBSProfit_lastweek missBSProfit_lastmonth99 missBSProfit_lastweek99 missBSihst_Profit_lastmonth	missBSbanksonly_bus_account missBSchamber missBSexport_license  missBStender missBSchanges_location missBSusd_loan_can_raise missBSamount_recentloan  missBSinsurance  missBSsaved_amount_bank missBSmix_bus_hh missBSfinancial_records missBScontact_bank missBStaxescosts missBSreceipt missBSt_courts  missBSt_police missBSt_govern missBSt_city_council missBSt_tax_aut missBSbanks_any_account missBSbanksonly_bus_account  missBSaccount_used_only_business missBSsave_home missBSrosca_sacco missBSbanks_saving missBSpropmaleworkers missBSinspected_municipality missBSAsked_for_bribe missBSthreats_to_shutdown missBSconfiscation missBSsexually_harassed missBSother_harassment missBScapital missBSno_inspected_taxes missBSno_inspected_other missBSconfident_no_bribe 
	 missF2has_BRC missF2has_TPIN missF2has_city_council missF2Revenue_lastmonth missF2Revenue_lastweek missF2Revenue_lastmonth99 missF2Revenue_lastweek99	missF2Profit_lastmonth missF2Profit_lastweek missF2Profit_lastmonth99 missF2Profit_lastweek99 missF2banksonly_bus_account missF2chamber missF2export_license missF2tender missF2changes_location  missF2loan_can_raise missF2amount_recentloan  missF2insurance  missF2mix_bus_hh missF2financial_records missF2contact_bank missF2taxescosts missF2receipt missF2t_courts  missF2t_police missF2t_govern missF2t_city_council missF2t_tax_aut missF2banks_any_account missF2banksonly_bus_account  missF2account_used_only_bus missF2save_home missF2rosca_sacco missF2banks_saving missF2no_inspected_municipalit missF2no_inspected_taxes missF2no_inspected_other missF2no_Asked_for_bribe missF2confident_no_bribe missF2no_threats_to_shutdown  missF2no_confiscation missF2no_sexually_harassed missF2no_other_harassment missF2capital missF2usd_saved_amount
	 missF2no_rosca_sacco missF2no_save_home missF2usd_saved_amount_bank missF2no_inspected_municipalit missF2no_inspected_taxes  missF2no_inspected_other missF2no_Asked_for_bribe missF2confident_no_bribe missF2no_threats_to_shutdown missF2no_confiscation missF2no_sexually_harassed missF2no_other_harassment
	 ;
#d cr 

renpfix F2_ F_

renpfix missF2 missF

gen round_fup = 2

save "$panel\BRIE_2ndfollowup_forpanel.dta", replace

restore

****************keep 1st follow-up relevant data for panel *****************
preserve

#d ;
keep id treatment treat1_BR treat2_BR_TPIN treat3_BR_Bank control int_BR int_BR_TPIN int_BR_Bank int_city_BR int_city_BR_TPIN int_city_BR_Bank reasonBRCnot_* freasonBRCnot_* took_br brc_tpin attendedtrainingday1 attendedtrainingday2 bankaccountopened City 
	 F_has_business F_no_attrition F_attrition F_closure $controls 
	 female lilongwe large_size firm_age high_capture Manufacturing Retail Services  					
	/* Baseline outcomes */
	 has_BRC has_TPIN has_city_council Total_workers2 Business_owner owner_started own_space innov electricity_access Num_competitors time_to_nearestbank owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed Seconday_completed Higher_education high_capture Financial_knowledge mother_enterpreneur mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt  usd_Revenue_lastmonth Revenue_lastmonth usd_Revenue_lastweek Revenue_lastweek usd_Revenue_lastmonth99 Revenue_lastmonth99 usd_Revenue_lastweek99 Revenue_lastweek99 ihst_Revenue_lastmonth usd_Profit_lastmonth  Profit_lastmonth usd_Profit_lastweek Profit_lastweek usd_Profit_lastmonth99 Profit_lastmonth99 usd_Profit_lastweek99  Profit_lastweek99 ihst_Profit_lastmonth	Total_workers2 number_days_workmonth usd_capital capital usd_assets assets propmaleworkers  borrowed_in_past usd_amount_recentloan amount_recentloan  any_account banks_any_account banksonly_bus_account account_used_only_business save_home  rosca_sacco banks_saving usd_saved_amount saved_amount usd_saved_amount99 saved_amount99 usd_saved_amount_bank saved_amount_bank mix_bus_hh bank_loan    usd_debt_outst_include  debt_outst_include benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown confiscation sexually_harassed sexuallyHarassed other_harassment receipt  num_customers num_customers_month chamber export_license tender changes_location usd_loan_can_raise loan_can_raise insurance Business_plan budget financial_records advert  other_activity netw_anyline contact_bank paidcitycouncilmktfee  taxescosts t_courts  t_police t_govern t_city_council t_tax_aut no_inspected_taxes no_inspected_other confident_no_bribe
	/* Follow-up outcomes */
	 F_has_BRC F_has_TPIN F_has_city_council F_Revenue_lastmonth F_Revenue_lastweek F_Revenue_lastmonth99 F_Revenue_lastweek99 F_ihst_Revenue_lastmonth	 F_Profit_lastmonth F_Profit_lastweek F_Profit_lastmonth99 F_Profit_lastweek99 F_ihst_Profit_lastmonth F_banksonly_bus_account F_export_license F_chamber F_tender F_changes_location F_loan_can_raise F_amount_recentloan F_insurance  F_saved_amount F_saved_amount_bank F_mix_bus_hh F_financial_records  F_contact_bank F_taxescosts F_receipt F_t_courts  F_t_police F_t_govern F_t_city_council F_t_tax_aut F_banks_any_account F_banksonly_bus_account  F_account_used_only_business F_save_home F_rosca_sacco F_banks_saving F_inspected_municipality F_inspected_taxes F_inspected_other F_Asked_for_bribe F_confident_no_bribe F_threats_to_shutdown F_confiscation F_sexually_harassed F_other_harassment
	/* missings vars */
	 missBShas_BRC missBShas_TPIN missBShas_city_council missBSRevenue_lastmonth missBSRevenue_lastweek missBSRevenue_lastmonth99 missBSRevenue_lastweek99 missBSihst_Revenue_lastmonth	missBSProfit_lastmonth missBSProfit_lastweek missBSProfit_lastmonth99 missBSProfit_lastweek99 missBSihst_Profit_lastmonth	missBSbanksonly_bus_account missBSchamber missBSexport_license  missBStender missBSchanges_location missBSusd_loan_can_raise missBSamount_recentloan  missBSinsurance  missBSsaved_amount_bank missBSmix_bus_hh missBSfinancial_records missBScontact_bank missBStaxescosts missBSreceipt missBSt_courts  missBSt_police missBSt_govern missBSt_city_council missBSt_tax_aut missBSbanks_any_account missBSbanksonly_bus_account  missBSaccount_used_only_business missBSsave_home missBSrosca_sacco missBSbanks_saving missBSpropmaleworkers missBSinspected_municipality missBSAsked_for_bribe missBSthreats_to_shutdown missBSconfiscation missBSsexually_harassed missBSother_harassment missBScapital missBSno_inspected_taxes missBSno_inspected_other missBSconfident_no_bribe 
	 missFhas_BRC missFhas_TPIN missFhas_city_council missFRevenue_lastmonth missFRevenue_lastweek missFRevenue_lastmonth99 missFRevenue_lastweek99	missFProfit_lastmonth missFProfit_lastweek missFProfit_lastmonth99 missFProfit_lastweek99 missFbanksonly_bus_account missFchamber missFexport_license missFtender missFchanges_location  missFloan_can_raise missFamount_recentloan  missFinsurance  missFmix_bus_hh missFfinancial_records missFcontact_bank missFtaxescosts missFreceipt missFt_courts  missFt_police missFt_govern missFt_city_council missFt_tax_aut missFbanks_any_account missFbanksonly_bus_account  missFaccount_used_only_bus missFsave_home missFrosca_sacco missFbanks_saving missFno_inspected_municipalit missFno_inspected_taxes missFno_inspected_other missFno_Asked_for_bribe missFconfident_no_bribe missFno_threats_to_shutdown  missFno_confiscation missFno_sexually_harassed missFno_other_harassment missFcapital missFusd_saved_amount
	missFno_rosca_sacco missFno_save_home  missFusd_saved_amount_bank  missFno_inspected_municipalit missFno_inspected_taxes  missFno_inspected_other missFno_Asked_for_bribe missFconfident_no_bribe missFno_threats_to_shutdown missFno_confiscation missFno_sexually_harassed missFno_other_harassment
;
#d cr 

gen round_fup = 1 

move round_fup treat1_BR

save "$panel\BRIE_1stfollowup_forpanel.dta", replace

restore

****************keep baseline relevant data for panel and append 1st followup, 2nd followup, 3rd followup and 4th followup*****************
#d ;
keep id treatment treat1_BR treat2_BR_TPIN treat3_BR_Bank control int_BR int_BR_TPIN int_BR_Bank int_city_BR int_city_BR_TPIN int_city_BR_Bank reasonBRCnot_* freasonBRCnot_* took_br brc_tpin attendedtrainingday1 attendedtrainingday2 bankaccountopened City firm_age 
	 $controls 
	 female lilongwe large_size firm_age high_capture Manufacturing Retail Services  					
	/* Baseline outcomes */
	 has_BRC has_TPIN has_city_council Total_workers2 Business_owner owner_started own_space innov electricity_access Num_competitors time_to_nearestbank owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed Seconday_completed Higher_education high_capture Financial_knowledge mother_enterpreneur mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt  usd_Revenue_lastmonth Revenue_lastmonth usd_Revenue_lastweek Revenue_lastweek usd_Revenue_lastmonth99 Revenue_lastmonth99 usd_Revenue_lastweek99 Revenue_lastweek99 ihst_Revenue_lastmonth usd_Profit_lastmonth  Profit_lastmonth usd_Profit_lastweek Profit_lastweek usd_Profit_lastmonth99 Profit_lastmonth99 usd_Profit_lastweek99  Profit_lastweek99 ihst_Profit_lastmonth	Total_workers2 number_days_workmonth usd_capital capital usd_assets assets propmaleworkers  borrowed_in_past usd_amount_recentloan amount_recentloan  any_account banks_any_account banksonly_bus_account account_used_only_business save_home  rosca_sacco banks_saving usd_saved_amount saved_amount usd_saved_amount99 saved_amount99 usd_saved_amount_bank saved_amount_bank mix_bus_hh bank_loan    usd_debt_outst_include  debt_outst_include benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown confiscation sexually_harassed sexuallyHarassed other_harassment receipt  num_customers num_customers_month chamber export_license tender changes_location usd_loan_can_raise loan_can_raise insurance Business_plan budget financial_records advert  other_activity netw_anyline contact_bank paidcitycouncilmktfee  taxescosts t_courts  t_police t_govern t_city_council t_tax_aut no_inspected_taxes no_inspected_other confident_no_bribe
	/* missings vars */
	 missBShas_BRC missBShas_TPIN missBShas_city_council missBSRevenue_lastmonth missBSRevenue_lastweek missBSRevenue_lastmonth99 missBSRevenue_lastweek99 missBSihst_Revenue_lastmonth	missBSProfit_lastmonth missBSProfit_lastweek missBSProfit_lastmonth99 missBSProfit_lastweek99 missBSihst_Profit_lastmonth	missBSbanksonly_bus_account missBSchamber missBSexport_license  missBStender missBSchanges_location missBSusd_loan_can_raise missBSamount_recentloan  missBSinsurance  missBSsaved_amount_bank missBSmix_bus_hh missBSfinancial_records missBScontact_bank missBStaxescosts missBSreceipt missBSt_courts  missBSt_police missBSt_govern missBSt_city_council missBSt_tax_aut missBSbanks_any_account missBSbanksonly_bus_account  missBSaccount_used_only_business missBSsave_home missBSrosca_sacco missBSbanks_saving missBSpropmaleworkers missBSinspected_municipality missBSAsked_for_bribe missBSthreats_to_shutdown missBSconfiscation missBSsexually_harassed missBSother_harassment missBScapital missBSno_inspected_taxes missBSno_inspected_other missBSconfident_no_bribe 
	 ;
#d cr 

gen round_fup = 0

	 
foreach var of varlist 	 has_BRC has_TPIN has_city_council Total_workers2 Business_owner  Financial_knowledge  Revenue_lastmonth Revenue_lastweek Revenue_lastmonth99  Revenue_lastweek99 ihst_Revenue_lastmonth Profit_lastmonth Profit_lastweek Profit_lastmonth99  Profit_lastweek99 ihst_Profit_lastmonth	number_days_workmonth  capital assets propmaleworkers  borrowed_in_past  amount_recentloan  any_account banks_any_account banksonly_bus_account account_used_only_business save_home  rosca_sacco banks_saving saved_amount  saved_amount99 saved_amount_bank mix_bus_hh bank_loan benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown confiscation sexually_harassed other_harassment receipt  num_customers chamber export_license tender changes_location loan_can_raise insurance budget financial_records advert  other_activity contact_bank paidcitycouncilmktfee  taxescosts t_courts  t_police t_govern t_city_council t_tax_aut {	 
cap drop F_`var'
rename `var' F_`var'
gen `var'=F_`var'
}

recode City (2=0)

move round_fup treat1_BR

append using "$panel\BRIE_1stfollowup_forpanel.dta"

append using "$panel\BRIE_2ndfollowup_forpanel.dta"

append using "$panel\BRIE_3rdfollowup_forpanel.dta"

append using "$panel\BRIE_4thfollowup_forpanel.dta"

sort id round_fup

tab round_fup, m



* Nominal variables adjustment
* Currency adjustment: MWK to USD
/*
Here we transform nominal variables in USD doing the following:
We calculate the average of exchange rates (e= MWK/USD) for each round-up period using the exchange rate information from Central Bank of Malawi.
*/

* Adjustment inputs
* Exchange rates
local e0=164.999  /* the average exchange rate of baseline data (December 2011 - April 2012)*/
local e1=349.463  /* the average exchange rate of the first round follow-up (November 2012 - March 2013)*/
local e2=422.617  /* the average exchange rate of the second round follow-up (November 2013 - March 2014)*/
local e3=463.617  /* the average exchange rate of the third round follow-up (November 2014 - March 2015)*/
local e4=510.950  /* the average exchange rate of the fourth round follow-up (June 2015 - October 2015)*/

global nominal  Revenue_lastweek Revenue_lastweek99 Revenue_lastmonth Profit_lastweek Profit_lastweek99 Profit_lastmonth Revenue_lastmonth99  Profit_lastmonth99 capital assets amount_recentloan  saved_amount saved_amount99 saved_amount_bank  

foreach var of varlist $nominal {
gen F_usd_`var'=.
replace F_usd_`var'= F_`var'/`e0' if round_fup==0
replace F_usd_`var'= F_`var'/`e1' if round_fup==1
replace F_usd_`var'= F_`var'/`e2' if round_fup==2
replace F_usd_`var'= F_`var'/`e3' if round_fup==3
replace F_usd_`var'= F_`var'/`e4' if round_fup==4
}


foreach var of varlist loan_can_raise  {
gen F_usd_`var'=.
replace F_usd_`var'= F_`var'/`e0' if round_fup==0
replace F_usd_`var'= F_`var'/`e1' if round_fup==1
replace F_usd_`var'= F_`var'/`e2' if round_fup==2
replace F_usd_`var'= F_`var'/`e3' if round_fup==3
replace F_usd_`var'= F_`var'/`e4' if round_fup==4
}


global othervars taxescosts  
foreach var of varlist $othervars  {
gen F_usd_`var'=.
replace F_usd_`var'= F_`var'/`e0' if round_fup==0
replace F_usd_`var'= F_`var'/`e1' if round_fup==1
replace F_usd_`var'= F_`var'/`e2' if round_fup==2
replace F_usd_`var'= F_`var'/`e3' if round_fup==3
replace F_usd_`var'= F_`var'/`e4' if round_fup==4

gen usd_`var'=.
replace usd_`var'= `var'/`e0' 
}


gen missFusd_loan_can_raise= missFloan_can_raise


* Check missing in usd vars. using MWK vars.
global missUSD Revenue_lastmonth Revenue_lastweek Profit_lastmonth Profit_lastweek Revenue_lastmonth99 Revenue_lastweek99 Profit_lastweek99 Profit_lastmonth99 capital amount_recentloan  saved_amount saved_amount_bank taxescosts 
foreach var of global missUSD {
	gen missBSusd_`var'= (missBS`var'==1)
	}

global M Revenue_lastmonth Revenue_lastweek Profit_lastmonth Profit_lastweek Revenue_lastmonth99 Revenue_lastweek99 Profit_lastweek99 Profit_lastmonth99 capital amount_recentloan  taxescosts
foreach var of global M {
	gen missFusd_`var'= (missF`var'==1)
	}

gen missFihst_Profit_lastmonth= (missFProfit_lastmonth==1)
gen missFihst_Revenue_lastmonth= (missFRevenue_lastmonth==1)

gen missBSihst_usd_Profit_lastmonth= (missBSusd_Profit_lastmonth==1)
gen missBSihst_usd_Revenue_lastmonth= (missBSusd_Revenue_lastmonth==1)

gen missFihst_usd_Profit_lastmonth= (missFusd_Profit_lastmonth==1)
gen missFihst_usd_Revenue_lastmonth= (missFusd_Revenue_lastmonth==1)


***********************************revenues and profits- inverse hyperbolic sine transformation in USD
gen ihst_usd_Profit_lastmonth = ln(usd_Profit_lastmonth+(((usd_Profit_lastmonth^2)+1)^0.5))

gen ihst_usd_Revenue_lastmonth = ln(usd_Revenue_lastmonth+(((usd_Revenue_lastmonth^2)+1)^0.5))

gen F_ihst_usd_Profit_lastmonth = ln(F_usd_Profit_lastmonth+(((F_usd_Profit_lastmonth^2)+1)^0.5))

gen F_ihst_usd_Revenue_lastmonth = ln(F_usd_Revenue_lastmonth+(((F_usd_Revenue_lastmonth^2)+1)^0.5))



************ OUTCOMES GENERATED USING USD VARS. *************************
tabmiss usd_saved_amount usd_Profit_lastmonth usd_assets	
foreach var of varlist usd_saved_amount usd_Profit_lastmonth usd_assets{
	display "`var'"
	replace `var'=0 if `var'==.
	replace F_`var'=0 if F_`var'==.
	}

************* OUTCOMES GENERATED USING BASELINE VARS. *******************
* High relative savings 
* Dummy of high relative savings (=1 if savings > median of savings at baseline)
* At baseline
sum usd_saved_amount , detail
sum usd_saved_amount99, detail
local cut1= r(p50)

gen highrelative_savings= 0
replace highrelative_savings= 1 if (usd_saved_amount > `cut1' ) 
tab highrelative_savings if round_fup==0, m

* By each follow-up round with baseline threshold 
gen F_highrelative_savings= 0
replace F_highrelative_savings= 1 if (F_usd_saved_amount > `cut1' ) 
tab F_highrelative_savings round_fup, m

gen missBShighrelative_savings= ( missBSusd_saved_amount==1) 
gen missFhighrelative_savings= ( missFusd_saved_amount==1 ) 


***********************************************************************
************************** Convertion *********************************
************** (more beneficial outcomes have higher scores) **********
***********************************************************************
* We convert all outcomes so that the sign of all of the variables in a family goes in the same direction 

* We convert the following outcomes variables:
* Outcome B: closure, propmaleworkers
* Outcome C1: save_home, rosca_sacco, save_ROSCA_SACCO, mix_bus_hh
* Outcome C2: inspected_municipality, inspected_taxes, inspected_other, Asked_for_bribe, threats_to_shutdown, confiscation, sexually_harassed, other_harassment

cap drop F_no_closure
gen	F_no_closure = 0 if F_closure==1
replace F_no_closure = 1 if F_closure==0 | round_fup==0


gen	F_no_inspected_taxes = 0 if F_inspected_taxes ==1
replace F_no_inspected_taxes = 1 if F_inspected_taxes ==0 | round_fup==0

gen F_no_inspected_other = 0 if F_inspected_other ==1
replace F_no_inspected_other = 1 if F_inspected_other ==0 | round_fup==0


global convert save_home rosca_sacco mix_bus_hh inspected_municipality  Asked_for_bribe threats_to_shutdown confiscation sexually_harassed other_harassment

foreach var of varlist $convert {
	gen	no_`var' = 0 if `var'==1	
	replace no_`var' = 1 if `var'==0
	gen missBSno_`var' = missBS`var'
	}

foreach var of varlist $convert {
	gen	F_no_`var' = 0 if F_`var'==1
	replace F_no_`var' = 1 if F_`var'==0
	}

rename missFno_inspected_municipalit missFno_inspected_municipality
rename missFaccount_used_only_bus missFaccount_used_only_business
gen missFno_mix_bus_hh=missFmix_bus_hh


************************** Final Check ********************************
/* Follow-ups outcomes of interest converted */
global outcomes has_BRC has_TPIN has_city_council usd_Revenue_lastmonth usd_Revenue_lastweek usd_Revenue_lastmonth99 usd_Revenue_lastweek99 ihst_usd_Revenue_lastmonth  usd_Profit_lastmonth usd_Profit_lastweek usd_Profit_lastmonth99 usd_Profit_lastweek99 ihst_usd_Profit_lastmonth   banksonly_bus_account chamber export_license tender changes_location usd_loan_can_raise usd_amount_recentloan  insurance  usd_saved_amount_bank highrelative_savings no_mix_bus_hh financial_records contact_bank usd_taxescosts receipt banksonly_bus_account  account_used_only_business no_save_home no_rosca_sacco banks_saving usd_loan_can_raise usd_amount_recentloan insurance usd_saved_amount_bank highrelative_savings no_mix_bus_hh financial_records no_inspected_municipality no_inspected_taxes no_inspected_other no_Asked_for_bribe confident_no_bribe no_threats_to_shutdown no_confiscation no_sexually_harassed no_other_harassment  highrelative_savings

* Final check: we replace any value that might be pending as missing from panel data do by 0.
foreach var of global outcomes {
	display "`var'"
	replace `var'=0 if `var'==.
	replace F_`var'=0 if F_`var'==.
	}


* Final check: we replace any value in missing vars. as 0 if we are sure that takes value 0 when firm is closed.
foreach var of global outcomes {
	display "`var'"
	replace missF`var'=0 if F_closure==1
	tab missF`var' F_closure
	}

	
*-- FOR IMPACT ANALYSIS ********************************

*** Opened BBA
gen BBA_NBS_opened = (bankaccountopened=="Yes")
tab BBA_ treatment if round_fup==0, r col



************************** ASSUMPTIONS ********************************
* Closed firms

* We code the outcomes of the firms that have closed and haven't open a new business as equal to zero.
* We will assume that a business which is closed does no longer have a formal license, a business bank account, or other such outcomes.
tab F_closure round_fup, m
gen closure=F_closure

foreach var of varlist $outcomes {
	replace F_`var'=0 if closure==1
	tab F_closure F_`var' if closure==1 & round_fup==1, m
	tab F_closure F_`var' if closure==1 & round_fup==2, m
	tab F_closure F_`var' if closure==1 & round_fup==3, m
	tab F_closure F_`var' if closure==1 & round_fup==4, m
	}

* Check
foreach var of varlist $outcomes {
	replace F_`var'=0 if closure==1 & round_fup==1
	replace F_`var'=0 if closure==1 & round_fup==2
	replace F_`var'=0 if closure==1 & round_fup==3
	replace F_`var'=0 if closure==1 & round_fup==4
	}

tab F_closure round_fup, m




************************ FOLLOW-UP ROUNDS DUMMIES REQUIRED ****************************

tab round_fup
tab round_fup if round_fup!=0, gen(FU)
sum FU*		


* Interactions
			global V treat1_BR treat2_BR_TPIN treat3_BR_Bank
			foreach v of global V {
			forvalues r=1/4{
			gen FU`r'`v'=FU`r'*`v'
			}
			}


************************** INTERACTIONS TERMS REQUIRED ********************************

* Interaction terms for heterogenous analysis:
* We rename the interaction variables.

* Female
tab female
tab int_BR 
tab int_BR_TPIN 
tab int_BR_Bank

rename int_BR int_female_BR
rename int_BR_TPIN int_female_BR_TPIN 
rename int_BR_Bank int_female_BR_Bank

* City
tab lilongwe
tab int_city_BR 
tab int_city_BR_TPIN 
tab int_city_BR_Bank

gen city = lilongwe


*************************** DEALING WITH MULTIPLE OUTCOMES *****************************
* In this section we follow Kling, Liebman, and Katz (2007)
/* The z-scores are calculated by
subtracting the control group mean and dividing by the control group standard deviation. Thus,
each component of the index has mean 0 and standard deviation one for the control group. 
See  creates_z-scores do file. */

**** z-scores *****
run "Paper for pub\Data\do files cleanning\creates_z-scores.do" 
drop z_*    // we drop z variables that we are not going to use //

run "Paper for pub\Data\do files cleanning\creates_z-scores_trust_institutions.do" 

rename F_avg_z_Revenue_FU F_avg_z_Revenue
rename avg_z_Revenue_BS avg_z_Revenue
rename F_avg_z_Profit_FU F_avg_z_Profit
rename avg_z_Profit_BS avg_z_Profit
	

*****************************************
*** LABELS
label var treat1_BR "Treatment 1: BRC"
label var treat2_BR_TPIN "Treatment 2: BRC + TPIN"
label var treat3_BR_Bank "Treatment 3: BRC + IS + BBA"
label var FU1 "Dummy 1= Round survey follow-up 1"
label var FU2 "Dummy 1= Round survey follow-up 2"
label var FU3 "Dummy 1= Round survey follow-up 3"
label var FU4 "Dummy 1= Round survey follow-up 4"
label var treatment "treatment status"
label var took_br "1= certificate delivered"

label var	City	" City"
label var female "1= Owner is female"
label var lilongwe "1= Lilongwe"
label var large_size "1= Large firm"
label var firm_age "Age of firm "
label var high_capture "1= High capture"
label var Manufacturing	"1= Business sector is manufacturing"
label var Retail	"1= Business sector is retail"
label var Services	"1= Business sector is services	"
					
label var Total_workers2 "Number of people working in business"
label var Business_owner "Number of owners" 
label var owner_started "1= Owner started business" 
label var own_space "1= Owns space where operates business"
label var innov "# new products introduced past 12 months "
label var electricity_access "1= Business with access to electricity "
label var Num_competitors "# of competitors "
label var time_to_nearestbank  	"Time to nearest bank (minutes) "
label var owner_age "Owner age"
label var Married "1= Married / Living with someone "
label var hh_decision_index "HH decision making index (0-100)"
label var Selfmainprovider "1= Main provider of income to household" 
label var Literate "1= Literate "
label var primary_completed "1= Primary school completed is max education "
label var Seconday_completed "1= Secondary school completed is max education "
label var Higher_education "1= Higher education completed "
label var Financial_knowledge "Financial Literacy knowledge (0-1) "
label var mother_enterpreneur "1= Mother was entrepreneur "
label var mother_wage_employt " 1= Mother in Wage Employment "
label var father_enterpreneur "1= Father was entrepreneur" 
label var father_wage_employt "1= Father in Wage Employment "
label var spouse_enterpreneur " 1= Spouse is entrepreneur" 
label var spouse_wage_employt " 1=Spouse in Wage Employment "
label var has_BRC "1= Has BRC at baseline" 					
label var has_TPIN "1= Has TPIN at baseline"
label var has_city_council "1= Has city council license at baseline"
label var usd_Revenue_lastweek99 "Revenue last week winsorized at 99th percentile (US$) at baseline"
label var usd_Revenue_lastmonth99 "Revenue last month winsorized at 99th percentile (US$) at baseline"
label var usd_Profit_lastweek99 "Profits last week winsorized at 99th percentile (US$) at baseline"
label var usd_Profit_lastmonth99 "Profits last month winsorized at 99th percentile (US$) at baseline"
label var number_days_workmonth "Number of days in a work month at baseline"
label var usd_capital "Capital (US$): Fixed Assets at baseline"
label var usd_assets "Assets (US$): Fixed Assets + Inventories + Cash at baseline"
label var propmaleworkers  "Proportion of male workers at baseline"			 
label var borrowed_in_past "Borrowed in the past  at baseline"
label var usd_amount_recentloan "Amount of a recent loan (US$) at baseline"
label var banks_any_account "Has bank account  at baseline"
label var banksonly_bus_account " Has bank account in name of business  at baseline"
label var account_used_only_business "Uses any account just for business purposes  at baseline"
label var save_home "1= Saves at home at baseline"
label var rosca_sacco "1= saves at ROSCA_SACCO at baseline"
label var banks_saving "1= Banks savings at baseline"
label var usd_saved_amount " Saved amount (US$) at baseline"
label var usd_saved_amount_bank "Saved amount at bank (US$) at baseline"
label var mix_bus_hh   "1= Takes business money whenever for HH at baseline"           
label var benefits_reg " Identifies benefit(s) of business registration at baseline"
label var inspected_municipality "1= Has been inspected by municipality before at baseline"  
label var Asked_for_bribe "1= Asked for bribe before at baseline"
label var threats_to_shutdown "1= Has received threats to shutdown at baseline"
label var confiscation "1= Has received threats to confiscation at baseline"
label var sexually_harassed "1= Has been sexually harassed at baseline"
label var other_harassment "1= Has received other harassment at baseline"
label var receipt  "1= Provides receipts at baseline"
label var num_customers "Number of customers at baseline"
label var tender "1= Tender at baseline"
label var budget "1= Has written a budget at baseline"
label var financial_records "1= Keeps financial records at baseline"
label var advert  "1= Advertises  at baseline"
label var other_activity "Other business activity "
label var	usd_Revenue_l~h	"	Revenue last month (US$) at baseline	"
label var	Revenue_lastm~h	"	Revenue last month (MWK) at baseline	"
label var	usd_Revenue_l~k	"	Revenue last week (US$) at baseline	"
label var	Revenue_lastw~k	"	Revenue last week (MWK) at baseline	"
label var	Revenue_lastm~9	"	Revenue last month winsorized at 99th percentile (MWK) at baseline	"
label var	Revenue_lastw~9	"	Revenue last week winsorized at 99th percentile (MWK) at baseline	"
label var	ihst_Revenue_~h	"	Revenue last month inverse hyperbolic sine transformation (MWK)	"
label var	usd_Profit_la~h	"	Profit last month (US$) at baseline	"
label var	Profit_lastmo~h	"	Profit last month (MWK) at baseline	"
label var	usd_Profit_la~k	"	Profit last week (US$) at baseline	"
label var	Profit_lastweek	"	Profit last week (MWK) at baseline	"
label var	Profit_lastm~99	"	Profit last month winsorized at 99th percentile (MWK) at baseline	"
label var	Profit_lastw~99	"	Profit last week winsorized at 99th percentile (MWK) at baseline	"
label var	ihst_Profit_l~h	"	Profit last month inverse hyperbolic sine transformation (MWK)	"
label var	capital	"	Capital (MWK): Fixed Assets at baseline	"
label var	assets	"	Assets (MWK): Fixed Assets + Inventories + Cash at baseline	"
label var	amount_recent~n	"	Amount recent loan (MWK) at baseline	"
label var	any_account	"	Has any account at baseline	"
label var	saved_amount	"	Saved amount (MWK) at baseline	"
label var	usd_saved_am~99	"	Saved amount winsorized at 99th percentile (U$S) at baseline	"
label var	saved_amount99	"	Saved amount winsorized at 99th percentile (MWK) at baseline	"
label var	saved_amount_~k	"	Saved amount at bank (MWK) at baseline	"
label var	bank_loan	"	1= Has a bank loan at baseline	"
label var	usd_debt_outs~e	"	Debt outstanding amount (U$S) at baseline (excludes zeros)	"
label var	debt_outst_in~o	"	Debt outstanding amount (MWK) at baseline (includes zeros)	"
label var	sexually_hara~d	"	1= Has been sexually harassed at baseline	"
label var	sexuallyHaras~d	"	1= Has been sexually harassed at baseline	"
label var	num_customers~h	"	Number of customers at baseline	"
label var	chamber	"	1= Belongs to Malawian Chamber of Commerce at baseline	"
label var	export_license	"	1= Has export license  at baseline	"
label var	changes_locat~n	"	1= Location of the business has changed at baseline	"
label var	usd_loan_can_~e	"	Amount that business can borrow in 2 weeks (U$S) at baseline	"
label var	loan_can_raise	"	Amount that business can borrow in 2 weeks (MWK) at baseline	"
label var	insurance	"	1= Has insurance for businessat baseline	"
label var	Business_plan	"	1= Has a business plan at baseline	"
label var	netw_anyline	"	1= Network contacts any sector at baseline	"
label var	contact_bank	"	1= Bank has contacted business at baseline	"
label var	paidcitycounc~e	"	1= Business pay city council market fee at baseline	"
label var	taxescosts	"	Taxes costs (MWK) at baseline	"
label var	t_courts	"	1= Trust in courts at baseline	"
label var	t_police	"	1= Trust in police at baseline	"
label var	t_govern	"	1= Trust in government at baseline	"
label var	t_city_council	"	1= Trust in city council at baseline	"
label var	t_tax_aut	"	1= Trust in tax authorities at baseline	"
label var	no_inspected_~s	"	1= Hasn't been inspected by taxes authorities at baseline	"
label var	no_inspected_~r	"	1= Hasn't been inspected by other authorities at baseline	"
label var	confident_no_~e	"	1= Doesn't feel confident to say no to bribes at baseline	"
label var	usd_taxescosts	"	Taxes costs (U$S) at baseline	"


label var avg_z_hyp_A_1_FU "Z score on formalization  (BRC, TPIN, IS + BBA) - all follow-ups and baseline info-"
label var avg_z_hyp_A_1_BS  "Z score on formalization  (BRC, TPIN, IS + BBA) at baseline"
label var missBSavg_z_hyp_A_1  "1= Z score on formalization is missing at baseline"
label var F_has_BRC "1= Has BRC - all follow-ups and baseline info-" 					
label var F_has_TPIN "1= Has TPIN - all follow-ups and baseline info-"
label var F_has_city_council "1= Has city council license - all follow-ups and baseline info-"

label var avg_z_hyp_A_2_FU "Z score on sales and profits - all follow-ups and baseline info-"
label var avg_z_hyp_A_2_BS  "Z score on sales and profits at baseline"
label var missBSavg_z_hyp_A_2 "1= Z score on sales and profits is missing at baseline"

label var F_avg_z_Revenue "Z score on sales - all follow-ups and baseline info- (USD last month, last week, winzorized at 99th percentile, and ihst)"
label var avg_z_Revenue  "Z score on sales at baseline (USD last month, last week, winzorized at 99th percentile, and ihst)"
label var F_avg_z_Profit "Z score on profits - all follow-ups and baseline info- (USD last month, last week, winzorized at 99th percentile, and ihst)"
label var avg_z_Profit  "Z score on profits at baseline (USD last month, last week, winzorized at 99th percentile, and ihst)"
label var F_usd_Revenue_lastmonth "Revenue last month (US$)- all follow-ups and baseline info-"
label var F_usd_Revenue_lastmonth99 "Revenue last month winsorized at 99th percentile (US$)- all follow-ups and baseline info-"
label var F_usd_Profit_lastmonth "Profit last month (US$)- all follow-ups and baseline info-"
label var F_usd_Profit_lastmonth99 "Profit last month winsorized at 99th percentile (US$)- all follow-ups and baseline info-"

label var avg_z_hyp_C2_FU "Z score on inspections and harassmentfrom state - all follow-ups and baseline info-"
label var avg_z_hyp_C2_BS "Z score on inspections and harassmentfrom state at baseline"
label var avg_z_hyp_FS_FU "Z score on financial services - all follow-ups and baseline info-"
label var avg_z_hyp_FS_BS "Z score on financial services at baseline"

label var F_banksonly_bus_account "1= Has a business bank account - all follow-ups and baseline info-"
label var F_chamber "1= Belongs to Malawian Chamber of Commerce - all follow-ups and baseline info-" 
label var F_export_license "1= Has export license - all follow-ups and baseline info-"
label var F_tender "1=Participates in Gov't tenders  - all follow-ups and baseline info-"
label var F_changes_location "1= Location of the business has changed - all follow-ups and baseline info-"

label var avg_z_hyp_UF_FU "Z scoreon use of finance - all follow-ups and baseline info-"
label var avg_z_hyp_UF_BS "Z scoreon use of finance at baseline"

label var F_banks_any_account "1= Has a bank account - all follow-ups and baseline info-"
label var F_usd_loan_can_raise "Amount that business can borrow in 2 weeks (U$S) - all follow-ups and baseline info-"
label var F_usd_amount_recentloan  "Amount borrowed (U$S) - all follow-ups and baseline info-"
label var F_insurance  "1= Has insurance for business - all follow-ups and baseline info-"
label var F_usd_saved_amount_bank "Amount in bank savings (U$S) - all follow-ups and baseline info-"
label var F_highrelative_savings "High relative savings above median - all follow-ups and baseline info-"
label var F_no_mix_bus_hh "1= Does not take business money for the household - all follow-ups and baseline info-"
label var F_financial_records "1= Business keeps financial records - all follow-ups and baseline info-"
label var F_contact_bank "1= Bank contacted business - all follow-ups and baseline info-"
label var F_usd_taxescosts "1= Taxes and market fees costs (US$) - all follow-ups and baseline info-"
label var F_receipt "1= Firm provides formal receipts - all follow-ups and baseline info-"
label var F_z_trustgov "1= Z score trust in courts, police, and national government (government institutions) - all follow-ups and baseline info-"
label var F_z_trustprivate  "1= Z score trust in city council and tax authorities - all follow-ups-"
label var F_banksonly_bus_account "1= Has bank account in name of business - all follow-ups and baseline info-"
label var F_account_used_only_business "1= Uses any account just for business purposes - all follow-ups and baseline info-"
label var F_no_save_home "1= Don't saves at home - all follow-ups and baseline info-"
label var F_no_rosca_sacco "1= Don't saves at ROSCA-SACCO - all follow-ups and baseline info-"
label var F_banks_saving "1= Saves at bank - all follow-ups and baseline info-"

label var F_attrition "1= Attrition - all follow-ups-"
label var F_closure "1= Business Has closed during the programa - all follow-ups info-"
label var closure "1= Business Has closed during the programa - all follow-ups info-"

label var	round_fup	"	Indicates round survey	"
label var	control	"	1= control group	"
label var	int_female_BR	"	Interaction between Treatment 1: BRC * female	"
label var	int_female_BR~N	"	Interaction between  Treatment 2: BRC + TPIN * female	"
label var	int_female_BR~k	"	Interaction between  Treatment 3: BRCE + IS + BBA * female	"
label var	int_city_BR	"	Interaction between Treatment 1: BRC * city	"
label var	int_city_BR_T~N	"	Interaction between  Treatment 2: BRC + TPIN * city	"
label var	int_city_BR_B~k	"	Interaction between  Treatment 3: BRCE + IS + BBA * city	"

label var	BBA_NBS_opened	"	1= Opened a BBA after information session	"
label var	FU1treat1_BR	"	Interaction between follow-up 1 dummy and treatment BRC status	"
label var	FU2treat1_BR	"	Interaction between follow-up 2 dummy and treatment BRC status	"
label var	FU3treat1_BR	"	Interaction between follow-up 3 dummy and treatment BRC status	"
label var	FU4treat1_BR	"	Interaction between follow-up 4 dummy and treatment BRC status	"
label var	FU1treat2_BR_~N	"	Interaction between follow-up 1 dummy and treatment TPIN status	"
label var	FU2treat2_BR_~N	"	Interaction between follow-up 2 dummy and treatment TPIN status	"
label var	FU3treat2_BR_~N	"	Interaction between follow-up 3 dummy and treatment tpin status	"
label var	FU4treat2_BR_~N	"	Interaction between follow-up 4 dummy and treatment TPIN status	"
label var	FU1treat3_BR_~k	"	Interaction between follow-up 1 dummy and treatment BRC + IS + BBA status	"
label var	FU2treat3_BR_~k	"	Interaction between follow-up 2 dummy and treatment BRC + IS + BBA status	"
label var	FU3treat3_BR_~k	"	Interaction between follow-up 3 dummy and treatment BRC + IS + BBA status	"
label var	FU4treat3_BR_~k	"	Interaction between follow-up 4 dummy and treatment BRC + IS + BBA status	"

label var   reasonBRCnot_combined "reasonBRCnot_combined"
label var	freasonBRCnot_combined	"	reasonBRCnot_combined -followup-	"
label var	freasonBRCnot_combined1	"	reasonBRCnot_combined==Already registered -followup-	"
label var	freasonBRCnot_combined2	"	reasonBRCnot_combined==Neeeded to consult spouse -followup-	"
label var	freasonBRCnot_combined3	"	reasonBRCnot_combined==Failed to locate/closed/moved -followup-	"
label var	freasonBRCnot_combined4	"	reasonBRCnot_combined==Refusal -followup-	"
label var	freasonBRCnot_combined5	"	reasonBRCnot_combined==No info on reason -followup-	"
label var	freasonBRCnot_combined6	"	reasonBRCnot_combined==Accepted registration -followup-	"

label var	F_Business_ow~r	"	Number of owners - all follow-ups and baseline info-	"
label var	F_capital	"	Capital (MWK): Fixed Assets - all follow-ups and baseline info-	"
label var	F_paidcitycou~e	"	1= Paid city council market fee- all follow-ups and baseline info-	"
label var	F_Asked_for_b~e	"	1= Has been asked for bribe - all follow-ups and baseline info-	"
label var	F_number_days~h	"	Number of days worked last month - all follow-ups and baseline info-	"
label var	F_budget	"	1= Has a budget - all follow-ups and baseline info-	"
label var	F_mix_bus_hh	"	1= Takes business money whenever for HH - all follow-ups and baseline info-	"
label var	F_Financial_k~e	"	Financial literacy knowledge (0-1)- all follow-ups and baseline info-	"
label var	F_Revenue_l~h99	"	Revenue last month winsorized at 99th percentile (MWK) - all follow-ups and baseline info-	"
label var	F_Profit_la~h99	"	Profit last month winsorized at 99th percentile (MWK) - all follow-ups and baseline info-	"
label var	F_Revenue_las~k	"	Revenue last week (MWK) - all follow-ups and baseline info-	"
label var	F_usd_Revenue~k	"	Revenue last week (U$S) - all follow-ups and baseline info-	"
label var	F_Profit_last~k	"	Profit last week (MWK) - all follow-ups and baseline info-	"
label var	F_usd_Profit_~k	"	Profit last week (U$S) - all follow-ups and baseline info-	"
label var	F_Revenue_l~k99	"	Revenue last week winsorized at 99th percentile (MWK) - all follow-ups and baseline info-	"
label var	F_Profit_la~k99	"	Profit last week winsorized at 99th percentile (MWK)  - all follow-ups and baseline info-	"
label var	F_usd_Reven~k99	"	Revenue last week winsorized at 99th percentile (U$S)  - all follow-ups and baseline info-	"
label var	F_usd_Profi~k99	"	Profit last week winsorized at 99th percentile (U$S)  - all follow-ups and baseline info-	"
label var	F_any_account	"	1= Has an account - all follow-ups and baseline info-"
label var	F_rosca_sacco	"	1= saves at ROSCA-SACCO  - all follow-ups and baseline info-"
label var	F_save_home	"	1= saves at home- all follow-ups and baseline info-"
label var	F_saved_amount	"	Saved amount (MWK)- all follow-ups and baseline info-"
label var	F_usd_saved_a~t	"	Saved amount (U$S) - all follow-ups and baseline info-"
label var	F_saved_amou~99	"	Saved amount winsorized at 99th percentile (MWK) - all follow-ups and baseline info-"
label var	F_usd_saved_~99	"	Saved amount winsorized at 99th percentile (U$S) - all follow-ups and baseline info-"
label var	F_saved_amoun~k	"	Saved amount at bank (MWK) - all follow-ups and baseline info-"
label var	F_borrowed_in~t	"	1=Borrowed in the past - all follow-ups and baseline info-"
label var	F_assets	"	Assets (MWK): Fixed Assets + Inventories + Cash - all follow-ups and baseline info-"
label var	F_usd_assets	"	Assets (US$): Fixed Assets + Inventories + Cash - all follow-ups and baseline info-"
label var	F_usd_capital	"	Capital (US$): Fixed Assets - all follow-ups and baseline info-"
label var	F_ihst_Profit~h	"	Profit last month inverse hyperbolic sine transformation (MWK)- all follow-ups and baseline info-"
label var	F_ihst_Revenu~h	"	Revenue last month inverse hyperbolic sine transformation (MWK) - all follow-ups and baseline info-"
label var	F_amount_rece~n	"	Amount of a recent loan (MWK) - all follow-ups and baseline info-"
label var	F_confiscation	"	1= Has received threats to confiscation - all follow-ups and baseline info-"
label var	F_num_customers	"	Number of customers- all follow-ups and baseline info-"
label var	F_advert	"	1= Advertises - all follow-ups and baseline info-"
label var	F_propmalewor~s	"	Proportion of male workers - all follow-ups and baseline info-"
label var	F_threats_to_~n	"	1= Has received threats to shutdown - all follow-ups and baseline info-"
label var	F_sexually_ha~d	"	1= Has been sexually harassed  - all follow-ups and baseline info-"
label var	F_other_haras~t	"	1= Has received other harassment - all follow-ups and baseline info-"
label var	F_other_activ~y	"	Other business activity - all follow-ups and baseline info-"
label var	F_taxescosts	"	Taxes costs (MWK)- all follow-ups and baseline info-"
label var	F_loan_can_ra~e	"	Amount that business can borrow in 2 weeks (MWK) - all follow-ups and baseline info-"
label var	F_no_inspecte~s	"	1= Hasn't been inspected by taxes authorities - all follow-ups and baseline info-	"
label var	F_no_inspecte~r	"	1= Hasn't been inspected by other authorities- all follow-ups and baseline info-	"
label var	F_confident_n~e	"	1= Doesn't feel confident to say no to bribes- all follow-ups and baseline info-	"
label var	F_t_courts	"	1= Trust in courts - all follow-ups and baseline info-	"
label var	F_t_police	"	1= Trust in police- all follow-ups and baseline info-	"
label var	F_t_govern	"	1= Trust in government- all follow-ups and baseline info-	"
label var	F_t_city_coun~l	"	1= Trust in city council - all follow-ups and baseline info-	"
label var	F_t_tax_aut	"	1= Trust in tax authorities - all follow-ups and baseline info-	"
label var	F_Total_worke~2	"	Number of people working in business  -follow-up info-	"
label var	F_no_attrition	"	1= No attrited all follow-ups	"
label var	F_has_business	"	1= Has a business - all follow-ups and baseline info-	"
label var	F_ihst_usd_Pr~h	"	Profit last month inverse hyperbolic sine transformation (U$S) - all follow-ups and baseline info-	"
label var	F_ihst_usd_Re~h	"	Revenue last month inverse hyperbolic sine transformation (U$S) - all follow-ups and baseline info-	"
label var	F_no_closure	"	1= Business hasn't closed- all follow-ups and baseline info-	"
label var	F_no_inspecte~y	"	1= Hasn't been inspected by municipality - all follow-ups and baseline info-	"
label var	F_no_Asked_fo~e	"	1= Hasn't been asked for bribe  - all follow-ups and baseline info-	"
label var	F_no_threats_~n	"	1= Hasn't been threated to shutdown - all follow-ups and baseline info-	"
label var	F_no_confisca~n	"	1= Hasn't been confiscated - all follow-ups and baseline info-	"
label var	F_no_sexually~d	"	1= Hasn't been sexually harrased - all follow-ups and baseline info-	"
label var	F_no_other_ha~t	"	1= Hasn't received other harassment - all follow-ups and baseline info-	"


label var	missBSRevenue~k	"	1= Revenue last week var is missing in Baseline	"
label var	missBSReven~k99	"	1= Revenue last week winsorized var is missing in Baseline	"
label var	missBSRevenue~h	"	1= Revenue last month var is missing in Baseline	"
label var	missBSReven~h99	"	1= Revenue last month winsorized var is missing in Baseline	"
label var	missBSProfit_~k	"	1= Profit last week var is missing in Baseline	"
label var	missBSProfi~k99	"	1= Profit last week winsorized var is missing in Baseline	"
label var	missBSProfit_~h	"	1= Profit last month var is missing in Baseline	"
label var	missBSProfi~h99	"	1= Profit last month winsorized var is missing in Baseline	"
label var	missBSbankson~t	"	1= banksonly_bus_account var is missing in Baseline	"
label var	missBSbanks_a~t	"	1= banks_any_account var is missing in Baseline	"
label var	missBSbanks_s~g	"	1= banks_saving  var is missing in Baseline	"
label var	missBSrosca_s~o	"	1= rosca-sacco varis missing in Baseline	"
label var	missBSsave_home	"	1= save_home var is missing in Baseline	"
label var	missBSaccount~s	"	1= account_used_only_business var is missing in Baseline	"
label var	missBSsaved_a~k	"	1= saved_amount_bank var is missing in Baseline	"
label var	missBShas_BRC	"	1= has_BRC var is missing in Baseline	"
label var	missBShas_TPIN	"	1= has_TPIN var is missing in Baseline	"
label var	missBShas_cit~l	"	1= has city council var is missing in Baseline	"
label var	missBSihst_Re~h	"	1= ihst_Revenue_lastmonth var is missing in Baseline	"
label var	missBSihst_Pr~h	"	1= ihst_Profit_lastmonth var is missing in Baseline	"
label var	missBSamount_~n	"	1=amount_recentloan var is missing in Baseline	"
label var	missBScapital	"	1= capital var is missing in Baseline	"
label var	missBSmix_bus~h	"	1= mix_bus var is missing in Baseline	"
label var	missBSfinanci~s	"	1= financial_records var is missing in Baseline	"
label var	missBSconfisc~n	"	1= confiscation var is missing in Baseline	"
label var	missBStender	"	1= tender var is missing in Baseline	"
label var	missBSpropmal~s	"	1= propmaleworkers var is missing in Baseline	"
label var	missBSinspect~y	"	1= inspected_municipality var is missing in Baseline	"
label var	missBSAsked_f~e	"	1= Asked_for_bribe var is missing in Baseline	"
label var	missBSthreats~n	"	1=threats_to_shutdown var is missing in Baseline	"
label var	missBSsexuall~d	"	1= sexuallyharrased var is missing in Baseline	"
label var	missBSother_h~t	"	1= other_harrasment var is missing in Baseline	"
label var	missBSreceipt	"	1= receipt var is missing in Baseline	"
label var	missBStaxesco~s	"	1= taxescosts is missing in Baseline	"
label var	missBSusd_loa~e	"	1= usd_loan_can_raise is missing in Baseline	"
label var	missBSinsurance	"	1= insurance is missing in Baseline	"
label var	missBSno_insp~s	"	1= no_inspected_taxes is missing in Baseline	"
label var	missBSno_insp~r	"	1=no_inspected_other  is missing in Baseline	"
label var	missBSconfide~e	"	1= confident_no_bribe  is missing in Baseline	"
label var	missBSchamber	"	1= chamber is missing in Baseline	"
label var	missBSexport_~e	"	1= export license is missing in Baseline	"
label var	missBScontact~k	"	1= contack bank is missing in Baseline	"
label var	missBSchanges~n	"	1= changes location is missing in Baseline	"
label var	missBSt_courts	"	1= trust in courts is missing in Baseline	"
label var	missBSt_police	"	1= trust in police is missing in Baseline	"
label var	missBSt_govern	"	1= trust in government is missing in Baseline	"
label var	missBSt_city_~l	"	1= trust in city council is missing in Baseline	"
label var	missBSt_tax_aut	"	1= trust in tax authorities is missing in Baseline	"
label var	missBSusd_Rev~h	"	1= usd_Revenue_lastmonth is missing in Baseline	"
label var	missBSusd_Rev~k	"	1= usd_Revenue_lastweek is missing in Baseline	"
label var	missBSusd_Pro~h	"	1= usd_Profit_lastmonth is missing in Baseline	"
label var	missBSusd_Pro~k	"	1= usd_Profit_lastweek is missing in Baseline	"
label var	missBSusd_R~h99	"	1= usd_Revenue_lastmonth winsorized is missing in Baseline	"
label var	missBSusd_R~k99	"	1= usd_Revenue_lastweek winsorized is missing in Baseline	"
label var	missBSusd_P~k99	"	1= usd_Profit_lastmonth winsorized is missing in Baseline	"
label var	missBSusd_P~h99	"	1= usd_Profit_lastweek winsorized is missing in Baseline	"
label var	missBSusd_cap~l	"	1= capital (U$S) is missing in Baseline	"
label var	missBSusd_amo~n	"	1=usd_amount_recentloan  is missing in Baseline	"
label var	missBSusd_sav~t	"	1= usd_saved_amount is missing in Baseline	"
label var	missBSusd_sav~k	"	1= usd_saved_amount_bank   is missing in Baseline	"
label var	missBSusd_tax~s	"	1= usd_taxescosts is missing in Baseline	"
label var	missBSihst_usd_Profit_lastmonth	"	1= ihst_usd_Profit_lastmonth   is missing in Baseline	"
label var	missBSihst_usd_Revenue_lastmonth 	"	1= ihst_usd_Revenue_lastmonth   is missing in Baseline	"

label var	missFusd_loan~e	"	1= sd_loan_can_raise var is missing in round surveys -all follow-ups and baseline-	"
label var	missFcontact_~k	"	1= contact_bank var is missing in round surveys -all follow-ups and baseline-	"
label var	missFRevenue_~k	"	1= Revenue_lastweek var is missing in round surveys -all follow-ups and baseline-	"
label var	missFRevenu~k99	"	1= Revenue_lastweek winsorized var is missing in round surveys -all follow-ups and baseline-	"
label var	missFProfit_l~k	"	1= Profit_lastweek var is missing in round surveys -all follow-ups and baseline-	"
label var	missFProfit~k99	"	1= Profit_lastweek winsorized var is missing in round surveys -all follow-ups and baseline-	"
label var	missFRevenue_~h	"	1= Revenue last month var is missing in round surveys -all follow-ups and baseline-	"
label var	missFRevenu~h99	"	1= Revenue last month winsorized var is missing in round surveys -all follow-ups and baseline-	"
label var	missFProfit_l~h	"	1= Profit_last month  var is missing in round surveys -all follow-ups and baseline-	"
label var	missFProfit~h99	"	1= Profit_last month winsorized var is missing in round surveys -all follow-ups and baseline-	"
label var	missFbanksonl~t	"	1= banksonly_bus_account var is missing in round surveys -all follow-ups and baseline-	"
label var	missFbanks_an~t	"	1= banks_any_account var is missing in round surveys -all follow-ups and baseline-	"
label var	missFbanks_sa~g	"	1= banks savings var is missing in round surveys -all follow-ups and baseline-	"
label var	missFrosca_sa~o	"	1= rosca sacco var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_rosca~o	"	1= no rosca sacco var is missing in round surveys -all follow-ups and baseline-	"
label var	missFsave_home	"	1= save home var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_save_~e	"	1= no save at home var is missing in round surveys -all follow-ups and baseline-	"
label var	missFaccount_~s	"	1= account_used_only_business var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_save~t	"	1= usd_saved_amount var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_save~k	"	1= usd_saved_amount_bank var is missing in round surveys -all follow-ups and baseline-	"
label var	missFloan_can~e	"	1= loan_can_raise var is missing in round surveys -all follow-ups and baseline-	"
label var	missFamount_r~n	"	1= amount_recentloan var is missing in round surveys -all follow-ups and baseline-	"
label var	missFcapital	"	1= capital var is missing in round surveys -all follow-ups and baseline-	"
label var	missFinsurance	"	1= insurance var is missing in round surveys -all follow-ups and baseline-	"
label var	missFmix_bus_hh	"	1= mix bus hh var is missing in round surveys -all follow-ups and baseline-	"
label var	missFfinancia~s	"	1= financial_records  var is missing in round surveys -all follow-ups and baseline-	"
label var	missFtender	"	1= tender var is missing in round surveys -all follow-ups and baseline-	"
label var	missFexport_l~e	"	1= export license var is missing in round surveys -all follow-ups and baseline-	"
label var	missFchamber	"	1= chamber var is missing in round surveys -all follow-ups and baseline-	"
label var	missFhas_BRC	"	1= has BRC var is missing in round surveys -all follow-ups and baseline-	"
label var	missFhas_TPIN	"	1= has TPIN var is missing in round surveys -all follow-ups and baseline-	"
label var	missFhas_city~l	"	1= has city council var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_inspe~y	"	1= no inspected by municipality var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_inspe~s	"	1= no_inspected_taxes  var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_inspe~r	"	1= no_inspected_other var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_Asked~e	"	1= no asked for bribe var is missing in round surveys -all follow-ups and baseline-	"
label var	missFconfiden~e	"	1= confident to say no to bribe var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_threa~n	"	1= no threats to shutdown var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_sexua~d	"	1= no sexually harrased var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_other~t	"	1= no other harrasment var is missing in round surveys -all follow-ups and baseline-	"
label var	missFno_confi~n	"	1= no confident to say no to bribe var is missing in round surveys -all follow-ups and baseline-	"
label var	missFreceipt	"	1= receipt var is missing in round surveys -all follow-ups and baseline-	"
label var	missFchanges_~n	"	1= changes location var is missing in round surveys -all follow-ups and baseline-	"
label var	missFtaxescosts	"	1= taxes costs var is missing in round surveys -all follow-ups and baseline-	"
label var	missFt_courts	"	1= trust in courts var is missing in round surveys -all follow-ups and baseline-	"
label var	missFt_police	"	1= trust in police var is missing in round surveys -all follow-ups and baseline-	"
label var	missFt_govern	"	1= trust in govern var is missing in round surveys -all follow-ups and baseline-	"
label var	missFt_city_c~l	"	1= trust in city council var is missing in round surveys -all follow-ups and baseline-	"
label var	missFt_tax_aut	"	1= trust in tax authorities var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Reve~h	"	1= Revenue last month (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Reve~k	"	1= Revenue last week (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Prof~h	"	1= Profit last month (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Prof~k	"	1= Profit last week (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Re~h99	"	1= Revenue last month winsorized (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Re~k99	"	1= Revenue last week winsorized (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Pr~k99	"	1= Profit last week winsorized (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_Pr~h99	"	1= Profit last month winsorized (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_capi~l	"	1= capital (U$S) var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_amou~n	"	1= usd_amount_recentloan var is missing in round surveys -all follow-ups and baseline-	"
label var	missFusd_taxe~s	"	1= usd_taxescosts var is missing in round surveys -all follow-ups and baseline-	"
label var	missFihst_Pro~h	"	1= ihst_Profit last month var is missing in round surveys -all follow-ups and baseline-	"
label var	missFihst_Rev~h	"	1= ihst_Revenue last month var is missing in round surveys -all follow-ups and baseline-	"
label var	missFihst_usd_Profit_lastmonth 	"	1= ihst_usd_Profit_lastmonth var is missing in round surveys -all follow-ups and baseline-	"
label var	missFihst_usd_Revenue_lastmonth	"	1= ihst_usd_Revenue_lastmonth var is missing in round surveys -all follow-ups and baseline-	"
label var	ihst_usd_Prof~h	"	Profit last month inverse hyperbolic sine transformation (U$S) at baseline	"
label var	ihst_usd_Reve~h	"	Revenue last month inverse hyperbolic sine transformation (U$S)	at baseline"
label var	highrelative_~s	"	1= high relative savings (over saved amount median) at baseline-	"
label var	missBShighrel~s	"	1=high relative savings var is missing in Baseline	"
label var	missFhighrela~s	"	1=high relative savings var is missing in round surveys -all follow-ups and baseline-	"
label var	no_save_home	"	1= Hasn't save at home at baseline	"
label var	missBSno_save~e	"	1=no_save_home var is missing in Baseline	"
label var	no_rosca_sacco	"	1= Hasn't save at rosca sacco at baseline	"
label var	missBSno_rosc~o	"	1= no_rosca_sacco var is missing in Baseline	"
label var	no_mix_bus_hh	"	1= Does not take business money for the household at baseline	"
label var	missBSno_mix_~h	"	1= no_mix_bus_hh is missing in Baseline	"
label var	no_inspected_~y	"	1= Hasn't been inspected by municipality at baseline	"
label var	missBSno_insp~y	"	1=no_inspected_municipality  is missing in Baseline	"
label var	no_Asked_for_~e	"	1= Hasn't been asked for bribe at baseline	"
label var	missBSno_Aske~e	"	1= no_Asked_for_bribe var is missing in Baseline	"
label var	no_threats_to~n	"	1= Hasn't been threated to shutdown at baseline	"
label var	missBSno_thre~n	"	1=no_threats_to_shutdown is missing in Baseline	"
label var	no_confiscation	"	 1= Hasn't been confiscated at basleine	"
label var	missBSno_conf~n	"	1= no_confiscation is missing in baseline	"
label var	no_sexually_h~d	"	1= Hasn't been sexually harrased  at baseline	"
label var	missBSno_sexu~d	"	1= no_sexually_harassed  var is missing in Baseline	"
label var	no_other_hara~t	"	1= Hasn't received other harassment at baseline	"
label var	missBSno_othe~t	"	1=no_other_harassment  var is missing in Baseline	"
label var	missFno_mix_b~h	"	1= F_no_mix_bus_hh var is missing in round surveys -all follow-ups and baseline-	"
label var	missBSavg_z_R~e	"	1= Revenue vars are missing in Baseline (then average z-score is missing)	"
label var	missBSavg_z_P~t	"	1= Profit vars are missing in Baseline (then average z-score is missing)	"
label var	missBSavg_z_~C2	"	1= inspections and harassment vars are missing in Baseline (then average z-score is missing)	"
label var	missBSavg_z_h~S	"	1= finance services are missing in Baseline (then average z-score is missing)	"
label var	missBSavg_z_h~F	"	1= use of finance vars are missing in Baseline (then average z-score is missing)	"
label var	z_t_courts_BS	"	z-score trust in courts at baseline	"
label var	z_t_courts_FU1	"	z-score trust in courts at follow-up1	"
label var	z_t_courts_FU2	"	z-score trust in courts at follow-up 2	"
label var	z_t_courts_FU3	"	z-score trust in courts at follow-up 3	"
label var	z_t_courts_FU4	"	z-score trust in courts at follow-up 4	"
label var	z_t_police_BS	"	z-score trust in police at baseline	"
label var	z_t_police_FU1	"	z-score trust in police at follow-up1	"
label var	z_t_police_FU2	"	z-score trust in police at follow-up 2	"
label var	z_t_police_FU3	"	z-score trust in police at follow-up 3	"
label var	z_t_police_FU4	"	z-score trust in police at follow-up 4	"
label var	z_t_govern_BS	"	z-score trust in government at baseline	"
label var	z_t_govern_FU1	"	z-score trust in government at follow-up1	"
label var	z_t_govern_FU2	"	z-score trust in government at follow-up 2	"
label var	z_t_govern_FU3	"	z-score trust in government at follow-up 3	"
label var	z_t_govern_FU4	"	z-score trust in government at follow-up 4	"
label var	z_trustgov	"	z-score trust in government institutions (courts, police, national government) at baseline	"
label var	missBSz_trust~v	"	1= z-score trust in government is missing in Baseline (courts, police and national government are missing)	"
label var	z_t_city_coun~S	"	z-score trust in city council at baseline	"
label var	z_t_city_coun~1	"	z-score trust in city council at follow-up1	"
label var	z_t_city_coun~2	"	z-score trust in city council at follow-up 2	"
label var	z_t_city_coun~3	"	z-score trust in city council at follow-up 3	"
label var	z_t_city_coun~4	"	z-score trust in city council at follow-up 4	"
label var	z_t_tax_aut_BS	"	z-score trust in tax authorities at baseline	"
label var	z_t_tax_aut_FU1	"	z-score trust in tax authorities at follow-up1	"
label var	z_t_tax_aut_FU2	"	z-score trust in tax authorities at follow-up 2	"
label var	z_t_tax_aut_FU3	"	z-score trust in tax authorities at follow-up 3	"
label var	z_t_tax_aut_FU4	"	z-score trust in tax authorities at follow-up 4	"
label var	z_trustprivate	"	z-score trust in institutions dealing private sector (taxes authorities and city council) at baseline	"
label var	missBSz_trust~e	"	1= z-score trust in institutions dealing private sector is missing in Baseline (trusting in tax authorities and city council are missing)	"
label var	city	"	1= lilongwe	"

*-- WE SAVE THE PANEL DATA	
	save "$panel\BRIE_finalpanel_Allfollowups_SEP2018.dta", replace
	save "Paper for pub\Data\BRIE_finalpanel_Allfollowups_SEP2018.dta", replace

/* panel data base created with 541 vars. at five time moments (BS, F1, F2, F3, F4)
10 strata vars. gender, city, lilongwe, high_capture, Manufacturing, Retail, Services, firm_age, two firm size vars.
1 id var.
1 round follow up var
4 treat vars.
46 strata dummy vars.
2 attrition vars.

15,010 obs.:
3002 from baseline data
2830 from F1, 2720 from F2, 2664 from F3, 2686 from F4

The prefix:
			F_ added to the beginning of a var name indicates that the var has follow-up and baseline info according to the specific round survey.
			vars wihouth prefix correspond to vars with baseline info, unless otherwise noted.
			missBS added to the beginning of a var name indicates the missings in baseline data of that var.
			missF added to the beginning of a var name indicates the missings in the follow-ups and baseline data of that var.
			
*/

