
** PURPOSE: 	This do-file calculates the z-scores of different results of the Malawi program. 
/*
				Part 1: Revenue average z-score
				Part 2: Profit average z-score
				
				
				Part 3: Hypothesis A average z-score
				Part 4: Hypothesis B average z-score
				Part 5: Hypothesis C1 average z-score
				Part 6: Hypothesis C2 average z-score
				Part 7: Hypothesis C3 average z-score
				Part 8: Hypothesis C4 average z-score
								*/


**************************************************************
* PART 1 *

* Revenue
global Revenue usd_Revenue_lastmonth usd_Revenue_lastweek usd_Revenue_lastmonth99 usd_Revenue_lastweek99 ihst_usd_Revenue_lastmonth  

foreach var of varlist $Revenue {
sum `var' if treatment==4 & round_fup==0
local controlmean=r(mean)
local controlsd=r(sd)

gen z_`var'_BS= (`var' - `controlmean')/ `controlsd'
sum  z_`var'_BS if treatment==4  & round_fup==0


forvalues r=1/4 {
sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup==`r'
local controlmean=r(mean)
local controlsd=r(sd)

gen z_`var'_FU`r'= (F_`var' - `controlmean')/ `controlsd' if round_fup==`r'
sum  z_`var'_FU`r' if treatment==4 & round_fup==`r'
}
}

# d;
gen avg_z_Revenue_BS=  
( z_usd_Revenue_lastmonth_BS + z_usd_Revenue_lastweek_BS + z_usd_Revenue_lastmonth99_BS + 
  z_usd_Revenue_lastweek99_BS + z_ihst_usd_Revenue_lastmonth_BS)/5
;
#d cr

gen F_avg_z_Revenue_FU = avg_z_Revenue_BS if round_fup==0


forvalues r=1/4 {
# d;
replace F_avg_z_Revenue_FU=  
( z_usd_Revenue_lastmonth_FU`r' + z_usd_Revenue_lastweek_FU`r' + z_usd_Revenue_lastmonth99_FU`r' + 
	z_usd_Revenue_lastweek99_FU`r' + z_ihst_usd_Revenue_lastmonth_FU`r' )/5
if round_fup==`r'
;
#d cr
}

# d;
gen missBSavg_z_Revenue= ( missBSusd_Revenue_lastmonth==1 & missBSusd_Revenue_lastweek==1 & 
							missBSusd_Revenue_lastmonth99==1 & missBSusd_Revenue_lastweek99==1 & missBSihst_usd_Revenue_lastmonth==1 )
;
#d cr
tab missBSavg_z_Revenue, m



**************************************************************
* PART 2 *
* Profit
global Profit usd_Profit_lastmonth usd_Profit_lastweek usd_Profit_lastmonth99 usd_Profit_lastweek99 ihst_usd_Profit_lastmonth  


foreach var of global Profit {
sum `var' if treatment==4 & round_fup==0
local controlmean=r(mean)
local controlsd=r(sd)

gen z_`var'_BS= (`var' - `controlmean')/ `controlsd'

 
forvalues r=1/4 {
sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup==`r'
local controlmean=r(mean)
local controlsd=r(sd)

gen z_`var'_FU`r'= (F_`var' - `controlmean')/ `controlsd' if round_fup==`r'
}
}

# d;
gen avg_z_Profit_BS=  
(z_usd_Profit_lastmonth_BS + z_usd_Profit_lastweek_BS + z_usd_Profit_lastmonth99_BS + z_usd_Profit_lastweek99_BS 
+ z_ihst_usd_Profit_lastmonth_BS )/5
;
#d cr

gen F_avg_z_Profit_FU = avg_z_Profit_BS if round_fup==0

forvalues r=1/4 {
# d;
replace F_avg_z_Profit_FU=  
( z_usd_Profit_lastmonth_FU`r' + z_usd_Profit_lastweek_FU`r' + z_usd_Profit_lastmonth99_FU`r' + z_usd_Profit_lastweek99_FU`r'
+ z_ihst_usd_Profit_lastmonth_FU`r')/5
if round_fup==`r'
;
#d cr
}

# d;
gen missBSavg_z_Profit= (
missBSusd_Profit_lastmonth==1 & missBSusd_Profit_lastweek==1 & missBSusd_Profit_lastmonth99==1 & 
missBSusd_Profit_lastweek99==1 & missBSihst_usd_Profit_lastmonth==1 )
;
#d cr
tab missBSavg_z_Profit, m




**************************************************************
* PART 3 *

* Hypothesis A_1
global H_A has_BRC has_TPIN has_city_council  
foreach var of global H_A {
sum `var' if treatment==4 & round_fup==0
local controlmean=r(mean)
local controlsd=r(sd)
tab `var'

gen z_`var'_BS= (`var' - `controlmean')/ `controlsd'
replace  z_`var'_BS=(`var' - `controlmean')/ 1 if z_`var'_BS==.  /* This is when controlsd is 0: vars that there are not in Baseline data for example has_BRC in Hyp A*/

*compare z_`var'_BS `var'
 
forvalues r=1/4 {
sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup==`r'
local controlmean=r(mean)
local controlsd=r(sd)
tab F_`var'

gen z_`var'_FU`r'= (F_`var' - `controlmean')/ `controlsd' if round_fup==`r'
replace z_`var'_FU`r'= (F_`var' - `controlmean')/1  if z_`var'_FU`r'==. & round_fup==`r' /* This is when controlsd is 0: vars that there are not in F1, F2 or F3 for example businesspractices in Hyp C4*/

}
}

# d;
gen avg_z_hyp_A_1_BS=  
(z_has_BRC_BS + z_has_TPIN_BS + z_has_city_council_BS )/3
;
#d cr

gen avg_z_hyp_A_1_FU = avg_z_hyp_A_1_BS if round_fup==0

forvalues r=1/4 {
# d;
replace avg_z_hyp_A_1_FU=  
(z_has_BRC_FU`r' + z_has_TPIN_FU`r' + z_has_city_council_FU`r' )/3
if round_fup==`r'
;
#d cr
}

# d;
gen missBSavg_z_hyp_A_1= (missBShas_BRC==1 & missBShas_TPIN==1 & missBShas_city_council==1 )
;
#d cr
tab missBSavg_z_hyp_A_1, m

* Hypothesis A_2
# d;
gen avg_z_hyp_A_2_BS=  
(z_ihst_usd_Profit_lastmonth_BS 
 + z_usd_Profit_lastmonth_BS + z_usd_Profit_lastweek_BS + z_usd_Profit_lastmonth99_BS + z_usd_Profit_lastweek99_BS
 +z_ihst_usd_Revenue_lastmonth_BS 
 + z_usd_Revenue_lastmonth_BS + z_usd_Revenue_lastweek_BS + z_usd_Revenue_lastmonth99_BS + z_usd_Revenue_lastweek99_BS)/10
;
#d cr

gen avg_z_hyp_A_2_FU = avg_z_hyp_A_2_BS if round_fup==0

forvalues r=1/4 {
# d;
replace avg_z_hyp_A_2_FU=  
(z_ihst_usd_Profit_lastmonth_FU`r' +
 z_usd_Profit_lastmonth_FU`r' + z_usd_Profit_lastweek_FU`r' + z_usd_Profit_lastmonth99_FU`r' + z_usd_Profit_lastweek99_FU`r'
 + z_ihst_usd_Revenue_lastmonth_FU`r' +
 z_usd_Revenue_lastmonth_FU`r' + z_usd_Revenue_lastweek_FU`r' + z_usd_Revenue_lastmonth99_FU`r' + z_usd_Revenue_lastweek99_FU`r')/10
if round_fup==`r'
;
#d cr
}

# d;
gen missBSavg_z_hyp_A_2= (missBSihst_usd_Profit_lastmonth==1 &  
missBSusd_Profit_lastmonth==1 & missBSusd_Profit_lastweek==1 & missBSusd_Profit_lastmonth99==1 & missBSusd_Profit_lastweek99==1 &
missBSihst_usd_Revenue_lastmonth==1 &  
missBSusd_Revenue_lastmonth==1 & missBSusd_Revenue_lastweek==1 & missBSusd_Revenue_lastmonth99==1 & missBSusd_Revenue_lastweek99==1)
;
#d cr
tab missBSavg_z_hyp_A_2, m


**************************************************************
* PART 2 *

* Hypothesis C2
global outcome_HC2 no_inspected_municipality no_inspected_taxes no_inspected_other no_Asked_for_bribe confident_no_bribe no_threats_to_shutdown no_confiscation no_sexually_harassed no_other_harassment

foreach var of global outcome_HC2 {
sum `var' if treatment==4 & round_fup==0
local controlmean=r(mean)
local controlsd=r(sd)

gen z_`var'_BS= (`var' - `controlmean')/ `controlsd'
replace  z_`var'_BS=0 if z_`var'_BS==.  /* This is when controlsd is 0: vars that there are not in Baseline data for example has_BRC in Hyp A*/

forvalues r=1/4 {
sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup==`r'
local controlmean=r(mean)
local controlsd=r(sd)

gen z_`var'_FU`r'= (F_`var' - `controlmean')/ `controlsd' if round_fup==`r'
replace z_`var'_FU`r'= (F_`var' - `controlmean')/1 if z_`var'_FU`r'==. & round_fup==`r' /* This is when controlsd is 0: vars that there are not in F1, F2 or F3 for example businesspractices in Hyp C4*/

}
}

# d;
gen avg_z_hyp_C2_BS=  
(z_no_inspected_municipality_BS + z_no_inspected_taxes_BS + z_no_inspected_other_BS + z_no_Asked_for_bribe_BS + z_confident_no_bribe_BS + 
z_no_threats_to_shutdown_BS + z_no_confiscation_BS + z_no_sexually_harassed_BS + z_no_other_harassment_BS)/9
;
#d cr

gen avg_z_hyp_C2_FU = avg_z_hyp_C2_BS if round_fup==0

forvalues r=1/4 {
# d;
replace avg_z_hyp_C2_FU= 
(z_no_inspected_municipality_FU`r' + z_no_inspected_taxes_FU`r' + z_no_inspected_other_FU`r' + z_no_Asked_for_bribe_FU`r' + z_confident_no_bribe_FU`r' + 
z_no_threats_to_shutdown_FU`r' + z_no_confiscation_FU`r' + z_no_sexually_harassed_FU`r' + z_no_other_harassment_FU`r' )/9
if round_fup==`r'
;
#d cr
}


# d;
gen missBSavg_z_hyp_C2= (missBSno_inspected_municipality== 1 & missBSno_inspected_taxes== 1 & missBSno_inspected_other== 1 & 
missBSno_Asked_for_bribe== 1 & missBSconfident_no_bribe== 1 & 
missBSno_threats_to_shutdown== 1 & missBSno_confiscation== 1 & 
missBSno_sexually_harassed== 1 & missBSno_other_harassment== 1 
)
;
#d cr
tab missBSavg_z_hyp_C2, m


*****************************************************************************************************************
* PART 3 *

* Hypothesis FS
foreach var of varlist banks_any_account banksonly_bus_account account_used_only_business no_save_home no_rosca_sacco banks_saving {
sum `var' if treatment==4 & round_fup==0 
local controlmean=r(mean)
local controlsd=r(sd)

cap drop z_`var'_BS
gen z_`var'_BS= (`var' - `controlmean')/ `controlsd'
replace  z_`var'_BS=0 if z_`var'_BS==.  /* This is when control sd is 0: vars that there are not in Baseline data for example has_BRC in Hyp A*/

 
forvalues r=1/4 {
sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup==`r' & closure==0
local controlmean=r(mean)
local controlsd=r(sd)

cap drop z_`var'_FU`r'
gen z_`var'_FU`r'= (F_`var' - `controlmean')/ `controlsd' if round_fup==`r' & closure==0
replace z_`var'_FU`r'= (F_`var' - `controlmean')/1 if z_`var'_FU`r'==. & round_fup==`r' & closure==0 /* This is when controlsd is 0: vars that there are not in F1, F2 or F3 for example businesspractices in Hyp C4*/

}
}

# d;
gen avg_z_hyp_FS_BS=  
(z_banks_any_account_BS + z_banksonly_bus_account_BS + z_account_used_only_business_BS + z_no_save_home_BS + z_no_rosca_sacco_BS + z_banks_saving_BS )/6
;
#d cr

gen avg_z_hyp_FS_FU = avg_z_hyp_FS_BS if round_fup==0

forvalues r=1/4 {
# d;
replace avg_z_hyp_FS_FU= 
(z_banks_any_account_FU`r' + z_banksonly_bus_account_FU`r' + z_account_used_only_business_FU`r' + z_no_save_home_FU`r' + z_no_rosca_sacco_FU`r' + z_banks_saving_FU`r' )/6
if round_fup==`r' & closure==0
;
#d cr
}

# d;
gen missBSavg_z_hyp_FS= ( missBSbanks_any_account== 1 &  missBSbanksonly_bus_account== 1 & missBSaccount_used_only_business== 1 & missBSno_save_home== 1 & missBSno_rosca_sacco== 1 & missBSbanks_saving== 1)
;
#d cr
tab missBSavg_z_hyp_FS, m



* Hypothesis UF
foreach var of varlist usd_loan_can_raise usd_amount_recentloan insurance usd_saved_amount_bank highrelative_savings no_mix_bus_hh financial_records {
sum `var' if treatment==4 & round_fup==0 
local controlmean=r(mean)
local controlsd=r(sd)

cap drop z_`var'_BS
gen z_`var'_BS= (`var' - `controlmean')/ `controlsd'
replace  z_`var'_BS=0 if z_`var'_BS==.  /* This is when control sd is 0: vars that there are not in Baseline data for example has_BRC in Hyp A*/

 
forvalues r=1/4 {
sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup==`r'
local controlmean=r(mean)
local controlsd=r(sd)

cap drop z_`var'_FU`r'
gen z_`var'_FU`r'= (F_`var' - `controlmean')/ `controlsd' if round_fup==`r'
replace z_`var'_FU`r'= (F_`var' - `controlmean')/1 if z_`var'_FU`r'==. & round_fup==`r' /* This is when controlsd is 0: vars that there are not in F1, F2 or F3 for example businesspractices in Hyp C4*/

}
}

# d;
gen avg_z_hyp_UF_BS=  
(z_usd_loan_can_raise_BS +  z_usd_amount_recentloan_BS + z_insurance_BS + z_usd_saved_amount_bank_BS+  z_highrelative_savings_BS 
+ z_no_mix_bus_hh_BS 
   + z_financial_records_BS )/7
;
#d cr


gen avg_z_hyp_UF_FU = avg_z_hyp_UF_BS if round_fup==0

forvalues r=1/4 {
# d;
replace avg_z_hyp_UF_FU= 
(z_usd_loan_can_raise_FU`r' +  z_usd_amount_recentloan_FU`r' + z_insurance_FU`r' + z_usd_saved_amount_bank_FU`r'+  
z_highrelative_savings_FU`r' + z_no_mix_bus_hh_FU`r'
  +  z_financial_records_FU`r' )/7
if round_fup==`r'
;
#d cr
}

# d;
gen missBSavg_z_hyp_UF= (missBSusd_loan_can_raise== 1 & missBSusd_amount_recentloan== 1 & missBSinsurance== 1 & 
 missBSusd_saved_amount_bank== 1  & missBShighrelative_savings== 1 & missBSno_mix_bus_hh== 1 & missBSfinancial_records==1)
;
#d cr
tab missBSavg_z_hyp_UF, m

